@@ -44,14 +44,19 @@ return [
 			'url' => '/box/{mailboxId}/thread/{id}',
 			'verb' => 'GET'
 		],
+		[
+			'name' => 'page#filteredThread',
+			'url' => '/box/{filter}/{mailboxId}/thread/{id}',
+			'verb' => 'GET'
+		],
 		[
 			'name' => 'page#draft',
 			'url' => '/box/{mailboxId}/thread/new/{draftId}',
 			'verb' => 'GET'
 		],
 		[
-			'name' => 'page#index',
-			'url' => '/',
+			'name' => 'page#filteredDraft',
+			'url' => '/box/{filter}/{mailboxId}/thread/new/{draftId}',
 			'verb' => 'GET'
 		],
 		[
@@ -89,6 +94,41 @@ return [
 			'url' => '/api/accounts/{id}/quota',
 			'verb' => 'GET'
 		],
+		[
+			'name' => 'tags#create',
+			'url' => '/api/tags',
+			'verb' => 'POST'
+		],
+		[
+			'name' => 'tags#update',
+			'url' => '/api/tags/{id}',
+			'verb' => 'PUT'
+		],
+		[
+			'name' => 'aliases#updateSignature',
+			'url' => '/api/accounts/{accountId}/aliases/{id}/signature',
+			'verb' => 'PUT'
+		],
+		[
+			'name' => 'contactIntegration#autoComplete',
+			'url' => '/api/contactIntegration/autoComplete/{term}',
+			'verb' => 'GET'
+		],
+		[
+			'name' => 'contactIntegration#addMail',
+			'url' => '/api/contactIntegration/add',
+			'verb' => 'PUT'
+		],
+		[
+			'name' => 'contactIntegration#newContact',
+			'url' => '/api/contactIntegration/new',
+			'verb' => 'PUT'
+		],
+		[
+			'name' => 'contactIntegration#match',
+			'url' => '/api/contactIntegration/match/{mail}',
+			'verb' => 'GET'
+		],
 		[
 			'name' => 'mailboxes#patch',
 			'url' => '/api/mailboxes/{id}',
@@ -154,6 +194,16 @@ return [
 			'url' => '/api/messages/{id}/flags',
 			'verb' => 'PUT'
 		],
+		[
+			'name' => 'messages#setTag',
+			'url' => '/api/messages/{id}/tags/{imapLabel}',
+			'verb' => 'PUT'
+		],
+		[
+			'name' => 'messages#removeTag',
+			'url' => '/api/messages/{id}/tags/{imapLabel}',
+			'verb' => 'DELETE'
+		],
 		[
 			'name' => 'messages#move',
 			'url' => '/api/messages/{id}/move',
@@ -185,13 +235,28 @@ return [
 			'verb' => 'GET'
 		],
 		[
-			'name' => 'settings#provisioning',
+			'name' => 'settings#index',
+			'url' => '/api/settings/provisioning',
+			'verb' => 'GET'
+		],
+		[
+			'name' => 'settings#createProvisioning',
 			'url' => '/api/settings/provisioning',
 			'verb' => 'POST'
 		],
+		[
+			'name' => 'settings#updateProvisioning',
+			'url' => '/api/settings/provisioning/{id}',
+			'verb' => 'POST'
+		],
+		[
+			'name' => 'settings#provision',
+			'url' => '/api/settings/provisioning/all',
+			'verb' => 'PUT'
+		],
 		[
 			'name' => 'settings#deprovision',
-			'url' => '/api/settings/provisioning',
+			'url' => '/api/settings/provisioning/{id}',
 			'verb' => 'DELETE'
 		],
 		[
@@ -223,6 +288,16 @@ return [
 			'name' => 'sieve#updateActiveScript',
 			'url' => '/api/sieve/active/{id}',
 			'verb' => 'PUT'
+		],
+		[
+			'name' => 'thread#delete',
+			'url' => '/api/thread/{id}',
+			'verb' => 'DELETE'
+		],
+		[
+			'name' => 'thread#move',
+			'url' => '/api/thread/{id}',
+			'verb' => 'POST'
 		]
 	],
 	'resources' => [
