@@ -67,6 +67,10 @@ OC.L10N.register(
     "Choose a file to add as attachment" : "Elektu dosieron aldonotan kiel kunsendaĵon",
     "Plain text" : "Ebenaĵa teksto",
     "Draft: " : "Malneto:",
+    "Mark unread" : "Marki kiel nelegita",
+    "Mark read" : "Marki kiel legita",
+    "Unselect" : "Malelekti",
+    "Select" : "Elekti",
     "Blind copy recipients only" : "Nur blindkopiaj ricevontoj",
     "Report this bug" : "Raporti tiun problemon",
     "Could not open mailbox" : "Ne eblis malfermi poŝtkesto",
@@ -75,14 +79,9 @@ OC.L10N.register(
     "Choose" : "Elekti",
     "Favorites" : "Pliŝataĵoj",
     "Other" : "Alia",
+    "Reply" : "Respondi",
     "Reply to sender only" : "Respondi nur al sendinto",
     "Forward" : "Antaŭen",
-    "Mark unread" : "Marki kiel nelegita",
-    "Mark read" : "Marki kiel legita",
-    "Unselect" : "Malelekti",
-    "Select" : "Elekti",
-    "Move" : "Movi",
-    "Delete" : "Forigi",
     "Attachments" : "Dosieraj aldonaĵoj",
     "Import into calendar" : "Importi en kalendaron",
     "Download attachment" : "Elŝuti kunsendaĵon",
@@ -93,6 +92,7 @@ OC.L10N.register(
     "Save all to Files" : "Konservi ĉiujn al „Dosieroj“",
     "Choose a folder to store the attachments in" : "Elektu dosierujon en kiu konservi la kunsendaĵojn",
     "The images have been blocked to protect your privacy." : "Bildoj ne montriĝis por protekti vian privatecon.",
+    "Move" : "Movi",
     "New message" : "Nova mesaĝo",
     "Settings" : "Agordoj",
     "Quota" : "Kvoto",
@@ -110,7 +110,7 @@ OC.L10N.register(
     "No message selected" : "Neniu mesaĝo elektita",
     "Signature …" : "Subskribo …",
     "Save signature" : "Konservi subskribon",
-    "Reply" : "Respondi",
+    "Delete" : "Forigi",
     "Import into {calendar}" : "Importi en {calendar}",
     "Event imported into {calendar}" : "Okazaĵo importis en {calendar}",
     "Could not create event" : "Ne eblis krei okazaĵon",
@@ -123,13 +123,11 @@ OC.L10N.register(
     "Mail app" : "Retpoŝtprogrameto",
     "Email: {email}" : "Retpoŝto: {email}",
     "General" : "Ĝenerala",
-    "Email address" : "Retpoŝtadreso",
     "IMAP" : "IMAP",
     "User" : "Uzanto",
     "Host" : "Gastigo",
     "Port" : "Pordo",
     "SMTP" : "SMTP",
-    "Apply and create/update for all users" : "Apliki kaj krei/ĝisdatigi por ĉiuj uzantoj",
     "Keyboard shortcuts" : "Fulmoklavoj",
     "Speed up your Mail experience with these quick shortcuts." : "Plirapidiĝu per tiuj fulmoklavoj.",
     "Compose new message" : "Krei novan mesaĝon",
