@@ -21,6 +21,7 @@ OC.L10N.register(
     "SMTP Password" : "Contraseña SMTP",
     "Save" : "Guardar",
     "Connect" : "Conectar",
+    "Signature" : "Firma",
     "Add mail account" : "Agregar cuenta de correo",
     "Use Gravatar and favicon avatars" : "Usar Gravatar y avatares favicon",
     "Select account" : "Selecciona la cuenta",
@@ -33,15 +34,13 @@ OC.L10N.register(
     "Message sent!" : "¡Mensaje enviado!",
     "Send" : "Enviar",
     "Choose a file to add as attachment" : "Selecciona el archivo a agregar como adjunto",
-    "No messages in this folder" : "No hay mensajes en esta carpeta",
     "Mark read" : "Marcar como leído",
     "Select" : "Seleccionar",
-    "Move" : "Mover",
-    "Delete" : "Borrar",
     "Choose" : "Seleccionar",
-    "Important" : "Importante",
     "Favorites" : "Favoritos",
     "Other" : "Otro",
+    "Reply" : "Responder",
+    "Forward" : "Adelante",
     "Import into calendar" : "Importar al calendario",
     "Download attachment" : "Descargar adjunto",
     "Save to Files" : "Guardar a Archivos",
@@ -49,22 +48,16 @@ OC.L10N.register(
     "Choose a folder to store the attachment in" : "Seleccciona la carpeta en la cual almacenar el adjunto",
     "Save all to Files" : "Guardar todo a Archivos",
     "The images have been blocked to protect your privacy." : "Las imágenes han sido bloqueadas para proteger tu privacidad. ",
-    "Show images from this sender" : "Mostrar imagenes de este remitente",
+    "Move" : "Mover",
     "New message" : "Mensaje nuevo",
     "Settings" : "Configuraciones ",
     "Quota" : "Cuota",
-    "Add folder" : "Add folder",
     "Saving" : "Guardando",
     "Remove account" : "Eliminar cuenta",
     "Cancel" : "Cancelar",
-    "Show all folders" : "Mostrar todas las carpetas",
-    "Collapse folders" : "Compactar carpetas",
     "Mark all as read" : "Marcar todos como leídos",
     "Clear cache" : "Borrar el caché",
-    "Delete folder" : "Borrar carpeta",
-    "Signature" : "Firma",
-    "Reply" : "Responder",
-    "Forward" : "Adelante",
+    "Delete" : "Borrar",
     "General" : "General",
     "User" : "Usuario",
     "Host" : "Servidor",
