@@ -60,7 +60,6 @@ OC.L10N.register(
     "This message came from a noreply address so your reply will probably not be read." : "Tämä viesti saapui noreply-osoitteesta, joten vastaustasi ei luultavasti lueta.",
     "The following recipients do not have a PGP key: {recipients}." : "Seuraavilla vastaanottajilla ei ole PGP-avainta: {recipients}.",
     "Write message …" : "Kirjoita viesti…",
-    "Can not save draft because this account does not have a drafts mailbox configured." : "Ei voida tallentaa luonnosta, koska tälle käyttäjälle ei ole määritelty postilaatikkoa luonnoksille.",
     "Saving draft …" : "Tallennetaan luonnosta…",
     "Draft saved" : "Luonnos tallennettu",
     "Upload attachment" : "Lähetä liite",
@@ -87,22 +86,6 @@ OC.L10N.register(
     "Rich text" : "Rikas teksti",
     "No messages" : "Ei viestejä",
     "Draft: " : "Luonnos: ",
-    "Blind copy recipients only" : "Vain piilokopion vastaanottajat",
-    "Load more" : "Lataa lisää",
-    "Could not delete message" : "Ei voitu poistaa viestiä",
-    "Report this bug" : "Ilmoita viasta",
-    "Could not open mailbox" : "Postilaatikkoa ei voitu avata",
-    "Loading messages" : "Ladataan viestejä",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Viestejäsi indeksoidaan. Tämä saattaa kestää hetken varsinkin suurikokoisissa postilaatikoissa.",
-    "Choose" : "Valitse",
-    "Important and unread" : "Tärkeät ja ei luetut",
-    "Important info" : "Tärkeää tietoa",
-    "Favorites" : "Suosikit",
-    "Other" : "Muu",
-    "Notify the sender" : "Ilmoita lähettäjälle",
-    "Reply to sender only" : "Vastaa vain lähettäjälle",
-    "Forward" : "Lähetä edelleen",
-    "Edit as new message" : "Muokkaa uutena viestinä",
     "Mark unimportant" : "Merkitse ei tärkeäksi",
     "Mark important" : "Merkitse tärkeäksi",
     "Mark unfavorite" : "Merkitse ei suosikiksi",
@@ -113,9 +96,24 @@ OC.L10N.register(
     "Mark as spam" : "Merkitse roskapostiksi",
     "Unselect" : "Poista valinta",
     "Select" : "Valitse",
-    "Move" : "Siirrä",
+    "Edit as new message" : "Muokkaa uutena viestinä",
+    "Blind copy recipients only" : "Vain piilokopion vastaanottajat",
+    "Could not delete message" : "Ei voitu poistaa viestiä",
+    "Load more" : "Lataa lisää",
+    "Report this bug" : "Ilmoita viasta",
+    "Could not open mailbox" : "Postilaatikkoa ei voitu avata",
+    "Loading messages" : "Ladataan viestejä",
+    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Viestejäsi indeksoidaan. Tämä saattaa kestää hetken varsinkin suurikokoisissa postilaatikoissa.",
+    "Choose" : "Valitse",
+    "Important and unread" : "Tärkeät ja ei luetut",
+    "Important info" : "Tärkeää tietoa",
+    "Favorites" : "Suosikit",
+    "Other" : "Muu",
+    "Notify the sender" : "Ilmoita lähettäjälle",
+    "Reply" : "Vastaa",
+    "Reply to sender only" : "Vastaa vain lähettäjälle",
+    "Forward" : "Lähetä edelleen",
     "View source" : "Näytä lähde",
-    "Delete" : "Poista",
     "Message source" : "Viestin lähde",
     "Message body" : "Viestin runko",
     "Attachments" : "Liitteet",
@@ -132,6 +130,7 @@ OC.L10N.register(
     "The images have been blocked to protect your privacy." : "Kuvat estettiin yksityisyytesi suojelemiseksi.",
     "Message frame" : "Viestiruutu",
     "Quoted text" : "Lainattu teksti",
+    "Move" : "Siirrä",
     "Moving" : "Siirretään",
     "New message" : "Uusi viesti",
     "Settings" : "Asetukset",
@@ -168,9 +167,9 @@ OC.L10N.register(
     "Oh Snap!" : "Oho!",
     "Signature …" : "Allekirjoitus…",
     "Save signature" : "Tallenna allekirjoitus",
-    "Could not load your message thread" : "Viestiketjua ei voitu ladata",
-    "Reply" : "Vastaa",
+    "Delete" : "Poista",
     "Remove" : "Poista",
+    "Could not load your message thread" : "Viestiketjua ei voitu ladata",
     "individual" : "yksittäinen",
     "domain" : "domaini",
     "Import into {calendar}" : "Tuo kalenteriin {calendar}",
@@ -186,13 +185,11 @@ OC.L10N.register(
     "The mail app allows users to read mails on their IMAP accounts." : "Tämä sähköpostisovellus mahdollistaa käyttäjien lukea sähköpostiviestejä IMAP-tileiltä.",
     "Email: {email}" : "Sähköposti: {email}",
     "General" : "Yleiset",
-    "Email address" : "Sähköpostiosoite",
     "IMAP" : "IMAP",
     "User" : "Käyttäjä",
     "Host" : "Palvelin",
     "Port" : "Portti",
     "SMTP" : "SMTP",
-    "Apply and create/update for all users" : "Toteuta ja luo/päivitä kaikille käyttäjille",
     "With the settings above, the app will create account settings in the following way:" : "Sovellus luo tiliasetukset yllä olevin asetuksin seuraavasti:",
     "Keyboard shortcut" : "Näppäimistön pikanäppäin",
     "Keyboard shortcuts" : "Pikanäppäimet",
