@@ -5,6 +5,7 @@ OC.L10N.register(
     "Updating account failed: " : "계정 업데이트 실패:",
     "Creating account failed: " : "계정 생성 실패: ",
     "Important mail" : "중요 메일",
+    "Unread mail" : "읽지 않은 메일",
     "Mails" : "메일",
     "Mail" : "메일",
     "💌 A mail app for Nextcloud" : "Nextcloud 메일 앱",
@@ -30,10 +31,14 @@ OC.L10N.register(
     "SMTP Password" : "SMTP 암호",
     "Save" : "저장",
     "Connect" : "연결",
+    "Account settings" : "계정 설정",
     "Change name" : "이름 변경",
     "Signature" : "서명",
+    "A signature is added to the text of new messages and replies." : "서명이 새로운 메시지 및 전달 메시지의 텍스트에 추가됩니다.",
     "Writing mode" : "쓰기 모드",
+    "Default folders" : "기본 폴더",
     "Mail server" : "메일 서버",
+    "Trusted senders" : "신뢰할 수 있는 발신자",
     "Add alias" : "별칭 추가",
     "Add mail account" : "메일 계정 추가",
     "Use Gravatar and favicon avatars" : "Gravatar 및 파비콘 아바타 사용",
@@ -50,6 +55,8 @@ OC.L10N.register(
     "Subject …" : "제목...",
     "The following recipients do not have a PGP key: {recipients}." : "다음의 수신자는 PGP key가 없습니다:{recipients}.",
     "Write message …" : "메시지 작성중...",
+    "Saving draft …" : "초안 저장 중...",
+    "Draft saved" : "초안 저장됨",
     "Upload attachment" : "첨부 파일 업로드",
     "Add attachment from Files" : "파일 앱에서 첨부 파일 추가",
     "Encrypt message with Mailvelope" : "Mailvelope로 메세지 암호화",
@@ -63,7 +70,7 @@ OC.L10N.register(
     "Send" : "보내기",
     "Encrypt and send" : "암호화해서 보내기",
     "Send unencrypted" : "비암호화 발송",
-    "Uploading {percent}% …" : "업로드 중 {percent}% …",
+    "Uploading {percent}% …" : "{percent}% 업로드 중...",
     "Choose a file to add as attachment" : "첨부할 파일을 선택하십시오",
     "Choose a file to share as a link" : "공유할 링크 파일을 선택하십시오",
     "Set up an account" : "계정 설정",
@@ -71,15 +78,6 @@ OC.L10N.register(
     "Rich text" : "서식 있는 텍스트",
     "No messages" : "메시지가 없음",
     "Draft: " : "임시 보관함",
-    "Load more" : "더 불러오기",
-    "Report this bug" : "이 오류 보고",
-    "Could not open mailbox" : "메일함을 열 수 없음",
-    "Loading messages" : "메세지를 불러오는 중",
-    "Choose" : "선택",
-    "Important info" : "중요 정보",
-    "Favorites" : "즐겨찾기",
-    "Other" : "기타",
-    "Forward" : "전달",
     "Mark unimportant" : "중요하지 않음 표시",
     "Mark important" : "중요함 표시",
     "Mark unfavorite" : "즐겨찾기 표시 제거",
@@ -90,8 +88,16 @@ OC.L10N.register(
     "Mark as spam" : "스팸 신고",
     "Unselect" : "선택 해제",
     "Select" : "선택",
-    "Move" : "이동",
-    "Delete" : "삭제",
+    "Load more" : "더 불러오기",
+    "Report this bug" : "이 오류 보고",
+    "Could not open mailbox" : "메일함을 열 수 없음",
+    "Loading messages" : "메세지를 불러오는 중",
+    "Choose" : "선택",
+    "Important info" : "중요 정보",
+    "Favorites" : "즐겨찾기",
+    "Other" : "기타",
+    "Reply" : "답장",
+    "Forward" : "전달",
     "Attachments" : "첨부파일",
     "Import into calendar" : "달력으로 가져오기",
     "Download attachment" : "첨부 파일 다운로드",
@@ -100,6 +106,7 @@ OC.L10N.register(
     "Choose a folder to store the attachment in" : "첨부 항목을 저장할 폴더 선택",
     "Save all to Files" : "모두 저장",
     "The images have been blocked to protect your privacy." : "개인 정보를 보호하기 위해 사진을 차단했습니다.",
+    "Move" : "이동",
     "New message" : "새로운 메시지",
     "Settings" : "설정",
     "Quota" : "할당량",
@@ -119,7 +126,7 @@ OC.L10N.register(
     "Not found" : "찾을 수 없음",
     "Signature …" : "서명 …",
     "Save signature" : "서명 저장",
-    "Reply" : "답장",
+    "Delete" : "삭제",
     "Airplane" : "여객기",
     "Reservation {id}" : "예약 {id}",
     "Train" : "열차",
