@@ -7,6 +7,7 @@ OC.L10N.register(
     "Embedded message %s" : "Įterptas laiškas %s",
     "Important mail" : "Svarbūs laiškai",
     "Unread mail" : "Neskaitytas paštas",
+    "Later" : "Vėliau",
     "Mails" : "El. laiškai",
     "Mail" : "Paštas",
     "💌 A mail app for Nextcloud" : "💌 Pašto programėlė, skirta Nextcloud",
@@ -63,7 +64,6 @@ OC.L10N.register(
     "This message came from a noreply address so your reply will probably not be read." : "Šis laiškas atėjo iš adreso, kuris nėra skirtas atsakyti, taigi jūsų atsakymas, tikriausiai, nebus perskaitytas.",
     "The following recipients do not have a PGP key: {recipients}." : "Šie gavėjai neturi PGP rakto: {recipients}.",
     "Write message …" : "Rašykite laišką…",
-    "Can not save draft because this account does not have a drafts mailbox configured." : "Nepavyko įrašyti juodraščio, nes šioje paskyroje nėra sukonfigūruota juodraščių pašto dėžutė.",
     "Saving draft …" : "Įrašomas juodraštis …",
     "Draft saved" : "Juodraštis įrašytas",
     "Upload attachment" : "Įkelti priedą",
@@ -76,6 +76,7 @@ OC.L10N.register(
     "Error sending your message" : "Klaida siunčiant jūsų laišką",
     "Go back" : "Grįžti",
     "Retry" : "Bandyti dar kartą",
+    "Send anyway" : "Vis tiek siųsti",
     "Message sent!" : "Laiškas išsiųstas!",
     "Write another message" : "Rašyti dar vieną laišką",
     "Send" : "Siųsti",
@@ -90,12 +91,19 @@ OC.L10N.register(
     "Rich text" : "Raiškusis tekstas",
     "No messages" : "Nėra laiškų",
     "Draft: " : "Juodraštis: ",
-    "Load more" : "Įkelti daugiau",
+    "Mark unimportant" : "Žymėti kaip nesvarbų",
+    "Mark important" : "Žymėti kaip svarbų",
+    "Mark unfavorite" : "Žymėti kaip nebemėgstamą",
+    "Mark favorite" : "Žymėti kaip mėgstamą",
+    "Mark unread" : "Žymėti kaip neskaitytą",
+    "Mark read" : "Žymėti kaip skaitytą",
+    "Unselect" : "Nuimti žymėjimą",
+    "Select" : "Pasirinkti",
+    "Edit as new message" : "Taisyti kaip naują laišką",
     "Could not delete message" : "Nepavyko ištrinti laiško",
+    "Load more" : "Įkelti daugiau",
     "_Mark {number} unread_::_Mark {number} unread_" : ["Žymėti {number} kaip neskaitytą","Žymėti {number} kaip neskaitytus","Žymėti {number} kaip neskaitytus","Žymėti {number} kaip neskaitytą"],
     "_Mark {number} read_::_Mark {number} read_" : ["Žymėti {number} kaip skaitytą","Žymėti {number} kaip skaitytus","Žymėti {number} kaip skaitytus","Žymėti {number} kaip skaitytą"],
-    "_Move {number}_::_Move {number}_" : ["Perkelti {number}","Perkelti {number}","Perkelti {number}","Perkelti {number}"],
-    "_Delete {number}_::_Delete {number}_" : ["Ištrinti {number}","Ištrinti {number}","Ištrinti {number}","Ištrinti {number}"],
     "Report this bug" : "Pranešti apie šią klaidą",
     "Could not open mailbox" : "Nepavyko atverti pašto dėžutės",
     "Loading messages" : "Įkeliami laiškai",
@@ -105,19 +113,9 @@ OC.L10N.register(
     "Important info" : "Svarbi informacija",
     "Favorites" : "Mėgstami",
     "Other" : "Kita",
+    "Reply" : "Atsakyti",
     "Reply to sender only" : "Atsakyti tik siuntėjui",
     "Forward" : "Persiųsti",
-    "Edit as new message" : "Taisyti kaip naują laišką",
-    "Mark unimportant" : "Žymėti kaip nesvarbų",
-    "Mark important" : "Žymėti kaip svarbų",
-    "Mark unfavorite" : "Žymėti kaip nebemėgstamą",
-    "Mark favorite" : "Žymėti kaip mėgstamą",
-    "Mark unread" : "Žymėti kaip neskaitytą",
-    "Mark read" : "Žymėti kaip skaitytą",
-    "Unselect" : "Nuimti žymėjimą",
-    "Select" : "Pasirinkti",
-    "Move" : "Perkelti",
-    "Delete" : "Ištrinti",
     "Attachments" : "Priedai",
     "Import into calendar" : "Importuoti į kalendorių",
     "Download attachment" : "Atsisiųsti priedą",
@@ -129,6 +127,11 @@ OC.L10N.register(
     "Choose a folder to store the attachments in" : "Pasirinkite aplanką, kuriame laikyti priedus",
     "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "Šis laiškas yra šifruotas naudojant PGP. Norėdami jį iššifruoti, įsidiekite Mailvelope.",
     "The images have been blocked to protect your privacy." : "Tam, kad būtų apsaugotas jūsų privatumas, paveikslai buvo užblokuoti.",
+    "Show" : "Rodyti",
+    "Show images temporarily" : "Laikinai rodyti paveikslus",
+    "Always show images from {sender}" : "Visada rodyti paveikslus nuo {sender}",
+    "Always show images from {domain}" : "Visada rodyti paveikslus iš {domain}",
+    "Move" : "Perkelti",
     "New message" : "Naujas laiškas",
     "Settings" : "Nustatymai",
     "Quota" : "Leidžiamas duomenų kiekis",
@@ -163,11 +166,14 @@ OC.L10N.register(
     "Could not load your draft" : "Nepavyko įkelti jūsų juodraščio",
     "Could not load original message" : "Nepavyko įkelti pradinio laiško",
     "No message selected" : "Nepasirinktas joks laiškas",
+    "New Contact" : "Naujas adresatas",
+    "Contact name …" : "Adresato vardas…",
+    "Add" : "Pridėti",
     "Disabled" : "Išjungta",
     "Enabled" : "Įjungta",
     "Signature …" : "Parašas…",
     "Save signature" : "Įrašyti parašą",
-    "Reply" : "Atsakyti",
+    "Delete" : "Ištrinti",
     "Remove" : "Šalinti",
     "No senders are trusted at the moment." : "Šiuo metu nėra patikimų siuntėjų.",
     "Could not remove trusted sender {sender}" : "Nepavyko pašalinti patikimo siuntėjo {sender}",
@@ -186,15 +192,12 @@ OC.L10N.register(
     "Email: {email}" : "El. paštas: {email}",
     "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} ties {host}:{port} ({ssl} šifravimas)",
     "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} ties {host}:{port} ({ssl} šifravimas)",
-    "Provision an account for every user" : "Parūpinti paskyrą kiekvienam naudotojui",
     "General" : "Bendra",
-    "Email address" : "El. pašto adresas",
     "IMAP" : "IMAP",
     "User" : "Naudotojas",
     "Host" : "Serveris",
     "Port" : "Prievadas",
     "SMTP" : "SMTP",
-    "Apply and create/update for all users" : "Taikyti ir sukurti/atnaujinti visiems naudotojams",
     "With the settings above, the app will create account settings in the following way:" : "Naudodama aukščiau esančius nustatymus, programėlė sukurs paskyrai nustatymus štai tokiu būdu: ",
     "Keyboard shortcut" : "Spartusis klavišas",
     "Keyboard shortcuts" : "Klaviatūros greitieji klavišai",
