@@ -13,23 +13,26 @@ OC.L10N.register(
     "Save" : "Salvar",
     "Connect" : "Connectar",
     "Write message …" : "Escriure un messatge…",
-    "Sending …" : "Mandadís ...",
+    "Sending …" : "Mandadís…",
     "Go back" : "Revenir en arrière",
     "Message sent!" : "Messatge mandat !",
     "Send" : "Mandar",
     "Choose a file to add as attachment" : "Causissètz un fichièr de jónher al messatge",
+    "Select" : "Select",
+    "Loading messages" : "Cargament dels messatges",
     "Choose" : "Causir",
     "Favorites" : "Favorits",
     "Other" : "Autre",
-    "Select" : "Select",
-    "Move" : "Move",
-    "Delete" : "Suprimir",
+    "Reply" : "Respondre",
     "Choose a folder to store the attachment in" : "Causissètz lo dorsièr dins lo qual enregistrar la pèça junta",
+    "Move" : "Move",
     "Settings" : "Paramètres",
+    "Loading …" : "Cargament…",
     "Cancel" : "Anullar",
     "Mark all as read" : "Marcar totes coma legits",
     "Clear cache" : "Voidar l'escondedor",
-    "Reply" : "Respondre",
+    "_{total} message_::_{total} messages_" : ["{total} messatge","{total} messatges"],
+    "Delete" : "Suprimir",
     "General" : "Generals",
     "User" : "User",
     "Keyboard shortcut" : "Acorchis de clavièr",
