@@ -7,10 +7,15 @@ OC.L10N.register(
     "Embedded message %s" : "嵌入式消息 %s",
     "Important mail" : "重要邮件",
     "Unread mail" : "未读邮件",
+    "Important" : "重要",
+    "Work" : "工作",
+    "Personal" : "个人",
+    "To Do" : "要做的事",
+    "Later" : "稍晚",
     "Mails" : "邮件",
     "Mail" : "邮件",
     "💌 A mail app for Nextcloud" : "💌 Nextcloud 上的一款邮件应用",
-    "**💌 A mail app for Nextcloud**\n\n- **🚀 Integration with other Nextcloud apps!** Currently Contacts, Calendar & Files – more to come.\n- **📥 Multiple mail accounts!** Personal and company account? No problem, and a nice unified inbox. Connect any IMAP account.\n- **🔒 Send & receive encrypted mails!** Using the great [Mailvelope](https://mailvelope.com) browser extension.\n- **🙈 We’re not reinventing the wheel!** Based on the great [Horde](http://horde.org) libraries.\n- **📬 Want to host your own mail server?** We don’t have to reimplement this as you could set up [Mail-in-a-Box](https://mailinabox.email)!" : "**💌 Nextcloud 上的一款邮件应用**\n\n- **🚀 与其他 Nextcloud 应用集成！** 当前已集成联系人、日历和文件应用 —— 后续还有更多。\n- **📥 多个邮箱账号！** 个人和公司账号？没问题，还有好用的统一收件箱。可连接任何 IMAP 账号。\n- **🔒 收发加密邮件！** 使用超棒的 [Mailvelope](https://mailvelope.com) 浏览器扩展。\n- **🙈 我们没有重复造轮子！** 基于超棒的 [Horde](http://horde.org) 软件库。\n- **📬 想托管您自己的邮件服务器？** 我们不需要重新实现这个功能，因为你们可以搭建 [Mail-in-a-Box](https://mailinabox.email)！",
+    "**💌 A mail app for Nextcloud**\n\n- **🚀 Integration with other Nextcloud apps!** Currently Contacts, Calendar & Files – more to come.\n- **📥 Multiple mail accounts!** Personal and company account? No problem, and a nice unified inbox. Connect any IMAP account.\n- **🔒 Send & receive encrypted mails!** Using the great [Mailvelope](https://mailvelope.com) browser extension.\n- **🙈 We’re not reinventing the wheel!** Based on the great [Horde](https://horde.org) libraries.\n- **📬 Want to host your own mail server?** We don’t have to reimplement this as you could set up [Mail-in-a-Box](https://mailinabox.email)!" : "**💌 Nextcloud 上的一款邮件应用**\n\n- **🚀 与其他 Nextcloud 应用集成！** 目前已集成联系人、日历和文件等应用 —— 后续还有更多。\n- **📥 多个邮箱账号！** 个人和公司账号？没问题，还有好用的统一收件箱。可连接任何 IMAP 账号。\n- **🔒 收发加密邮件！** 使用超棒的 [Mailvelope](https://mailvelope.com) 浏览器扩展。\n- **🙈 我们没有重复造轮子！** 基于超棒的 [Horde](http://horde.org) 软件库。\n- **📬 想托管您自己的邮件服务器？** 我们不需要重新实现这个功能，因为你们可以搭建 [Mail-in-a-Box](https://mailinabox.email)！",
     "Drafts are saved in:" : "草稿邮件被保存于：",
     "Sent messages are saved in:" : "已发送邮件被保存于：",
     "Deleted messages are moved in:" : "已删除邮件被移动到：",
@@ -55,6 +60,8 @@ OC.L10N.register(
     "Show keyboard shortcuts" : "显示键盘快捷方式",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "允许该应用收集有关您的互动的数据。 根据这些数据，该应用程序将适应您的偏好。 数据将仅存储在本地。",
     "Put my text to the bottom of a reply instead of on top of it." : "把我的信息放在回复的最下面，而不是最上面。 ",
+    "Automatically classify importance of new email" : "自动分类新邮件的重要性 ",
+    "Could not update preference" : "无法更新首选项",
     "From" : "发件人",
     "Select account" : "选择账号",
     "To" : "收件人",
@@ -68,7 +75,7 @@ OC.L10N.register(
     "This message came from a noreply address so your reply will probably not be read." : "标记的消息来自一个无法回复的地址，您的回复可能不会被阅读。",
     "The following recipients do not have a PGP key: {recipients}." : "以下收件人没有 PGP 密钥：{recipients}。",
     "Write message …" : "编写消息...",
-    "Can not save draft because this account does not have a drafts mailbox configured." : "无法保存草稿，因为该账号没有配置草稿邮箱。",
+    "Cannot save draft because this account does not have a drafts mailbox configured." : "无法保存草稿，因为该账户没有配置草稿邮箱。 ",
     "Saving draft …" : "正在保存草稿 …",
     "Draft saved" : "草稿已保存",
     "Upload attachment" : "上传附件",
@@ -82,6 +89,8 @@ OC.L10N.register(
     "Error sending your message" : "发送您的消息时出错",
     "Go back" : "后退",
     "Retry" : "重试",
+    "Warning sending your message" : "对发送信息提出警告",
+    "Send anyway" : "不论如何都要发送",
     "Message sent!" : "消息已发送！",
     "Write another message" : "再写一条消息",
     "Add share link from {productName} Files" : "添加来自 {productName} 文件的共享链接",
@@ -90,6 +99,7 @@ OC.L10N.register(
     "Send unencrypted" : "不加密发送",
     "Message {id} could not be found" : "消息 {id} 未找到",
     "No sent mailbox configured. Please pick one in the account settings." : "没有配置发送邮箱。请在账号设置中选择一个。",
+    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "你在To 和/或 Cc 中正尝试发送给许多收件人。考虑使用 Bcc 来隐藏收件人地址。",
     "Uploading {percent}% …" : "正在上传 {percent}% …",
     "Choose a file to add as attachment" : "选择文件添加为附件",
     "Choose a file to share as a link" : "选择要共享的文件作为链接",
@@ -101,18 +111,32 @@ OC.L10N.register(
     "No messages in this mailbox" : "此邮箱中没有消息",
     "No messages" : "没有消息",
     "Draft: " : "草稿: ",
+    "Mark unimportant" : "标记为不重要",
+    "Mark important" : "标记为重要",
+    "Mark unfavorite" : "取消收藏",
+    "Mark favorite" : "收藏",
+    "Mark unread" : "标记为未读",
+    "Mark read" : "标记为已读",
+    "Mark not spam" : "标记为非垃圾邮件",
+    "Mark as spam" : "标记为垃圾邮件",
+    "Unselect" : "取消选择",
+    "Select" : "选择",
+    "Edit tags" : "编辑标签",
+    "Move thread" : "移动线程",
+    "Edit as new message" : "编辑为新消息",
+    "Delete thread" : "删除线程",
     "Blind copy recipients only" : "仅向收件人发送无信头副本",
-    "Load more" : "加载更多",
     "No trash mailbox configured" : "没有配置垃圾邮箱",
     "Could not delete message" : "无法删除消息",
+    "Load more" : "加载更多",
     "_Mark {number} unread_::_Mark {number} unread_" : ["标记 {number} 封未读"],
     "_Mark {number} read_::_Mark {number} read_" : ["标记  {number} 封已读"],
     "_Unfavorite {number}_::_Unfavorite {number}_" : ["取消收藏 {number} 封"],
     "_Favorite {number}_::_Favorite {number}_" : ["收藏 {number} 封"],
     "_Unselect {number}_::_Unselect {number}_" : ["取消选中 {number} 封"],
-    "_Move {number}_::_Move {number}_" : ["移动 {number} 封"],
+    "_Move {number} thread_::_Move {number} threads_" : ["移动 {number} 个线程"],
     "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["转发 {number} 封为附件"],
-    "_Delete {number}_::_Delete {number}_" : ["删除 {number} 封"],
+    "_Delete {number} thread_::_Delete {number} threads_" : ["删除 {number} 个线程"],
     "Report this bug" : "报告此问题",
     "Could not open mailbox" : "无法打开邮箱",
     "Loading messages" : "正在加载消息",
@@ -129,23 +153,13 @@ OC.L10N.register(
     "Notify the sender" : "通知发件人",
     "You sent a read confirmation to the sender of this message." : "您向此消息的发送方发送了一个已读确认。",
     "Could not send mdn" : "无法发送 mdn",
+    "Reply" : "回复",
     "Reply to sender only" : "只回复发送者",
     "Forward" : "转发",
-    "Edit as new message" : "编辑为新消息",
-    "Mark unimportant" : "标记为不重要",
-    "Mark important" : "标记为重要",
-    "Mark unfavorite" : "取消收藏",
-    "Mark favorite" : "收藏",
-    "Mark unread" : "标记为未读",
-    "Mark read" : "标记为已读",
-    "Mark not spam" : "标记为非垃圾邮件",
-    "Mark as spam" : "标记为垃圾邮件",
-    "Unselect" : "取消选择",
-    "Select" : "选择",
-    "Move" : "移动",
+    "Move message" : "移动消息",
     "View source" : "查看来源",
     "Download thread data for debugging" : "下载线程数据以进行调试",
-    "Delete" : "删除",
+    "Delete message" : "删除消息",
     "Message source" : "消息来源",
     "Message body" : "消息正文",
     "Attachments" : "附件",
@@ -160,11 +174,16 @@ OC.L10N.register(
     "Choose a folder to store the attachments in" : "选择附件保存的目录",
     "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "此消息已使用 PGP 加密。 安装 Mailvelope 对其进行解密。",
     "The images have been blocked to protect your privacy." : "图片已被禁用，以保护您的隐私。",
+    "Show" : "显示",
+    "Show images temporarily" : "暂时显示图像",
     "Always show images from {sender}" : "始终显示来自 {sender} 的邮件",
     "Always show images from {domain}" : "始终显示来自 {domain} 的图片",
     "Message frame" : "消息框",
     "Quoted text" : "引用文字",
+    "Move" : "移动",
     "Moving" : "移动",
+    "Moving thread" : "正在移动线程",
+    "Moving message" : "正在移动消息",
     "New message" : "新建消息",
     "Settings" : "设置",
     "Quota" : "配额",
@@ -203,6 +222,11 @@ OC.L10N.register(
     "Could not load your draft" : "无法加载您的草稿",
     "Could not load original message" : "无法加载初始消息",
     "No message selected" : "没有选择消息",
+    "Contacts with this address" : "使用此地址的联系人 ",
+    "Add to Contact" : "添加到联系人",
+    "New Contact" : "新联系人",
+    "Contact name …" : "联系人姓名 …",
+    "Add" : "新增",
     "Disabled" : "已禁用",
     "Enabled" : "已启用",
     "Sieve Host" : "Sieve 主机",
@@ -217,10 +241,14 @@ OC.L10N.register(
     "Save sieve settings" : "保存 sieve 设置",
     "Save sieve script" : "保存 sieve 脚本",
     "Signature …" : "签名...",
+    "Place signature above quoted text" : "把签名放在引用文本上方",
     "Save signature" : "保存签名",
-    "Could not load your message thread" : "无法加载您的消息线线程",
-    "Reply" : "回复",
+    "Delete" : "删除",
     "Remove" : "删除",
+    "Add tag" : "添加标签",
+    "Saving tag …" : "正在保存标签 …",
+    "An error occurred, unable to create the tag." : "发生了一个错误，无法创建标签",
+    "Could not load your message thread" : "无法加载您的消息线线程",
     "No senders are trusted at the moment." : "当前没有发件人是受信任的",
     "Could not remove trusted sender {sender}" : "无法删除受信任的发件人 {sender} ",
     "individual" : "个别的",
@@ -237,14 +265,32 @@ OC.L10N.register(
     "Mail app" : "邮件应用",
     "The mail app allows users to read mails on their IMAP accounts." : "邮件应用允许用户阅读其 IMAP 账号中的邮件。",
     "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "在这里你可以找到实例范围的设置。用户特定的设置在应用本身里（左下角）。",
+    "A provisioning configuration will provision all accounts with a matching email address." : "服务开通配置将给所有帐户提供匹配的电子邮件地址。",
+    "Using the wildcard (*) in the provisioning domain field will create a configuration that applies to all users, provided they do not match another configuration." : "在服务开通域字段中使用通配符 (*) 将创建一个适用于所有用户的配置，倘若他们不匹配其他配置。",
+    "The provisioning mechanism will prioritise specific domain configurations over the wildcard domain configuration." : "在开通机制中，特定的域配置的优先级高于通配符域配置。",
+    "Should a new matching configuration be found after the user was already provisioned with another configuration, the new configuration will take precedence and the user will be reprovisioned with the configuration." : "如果在用户已经被提供了另一个配置之后找到了新的匹配的配置，则新配置具有更高优先级，将替代原先配置。",
+    "There can only be one configuration per domain and only one wildcard domain configuration." : "每个域只能有一个配置，并且只有一个通配符域配置。 ",
+    "These settings can be used in conjunction with each other." : "这些设置可以相互结合使用。 ",
+    "If you only want to provision one domain for all users, use the wildcard (*)." : "如果您只想为所有用户提供一个域，请使用通配符(*)。",
+    "Add new config" : "添加新配置",
+    "Provision all accounts" : "开通所有账户",
+    "Successfully updated config for \"{domain}\"" : "成功更新了  \"{domain}\" 的配置",
+    "Error saving config" : "保存配置时出错",
+    "Saved config for \"{domain}\"" : "已保存 \"{domain}\" 的配置",
+    "Could not save provisioning setting" : "无法保存服务开通设置",
+    "There was an error when provisioning accounts." : "开通账户时发生一个错误",
+    "Successfully deleted and deprovisioned accounts for \"{domain}\"" : "成功删除和没收了  \"{domain}\" 的账户",
+    "Error when deleting and deprovisioning accounts for \"{domain}\"" : "删除和没收  \"{domain}\" 账户时出错",
+    "_Successfully provisioned {count} account._::_Successfully provisioned {count} accounts._" : ["成功开通了 {count} 个账户"],
+    "Domain Match: {provisioningDomain}" : "域名匹配：{provisioningDomain}",
     "Email: {email}" : "电子邮件：{email}",
     "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} 在 {host}:{port} ({ssl} 加密)",
     "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} 在 {host}:{port} ({ssl} 加密)",
     "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "Sieve：{user} 位于 {host}:{port} ({ssl} encryption)",
-    "You can configure a template for account settings, from which all users will get an account provisioned from." : "您可以为账号设置配置模板，所有用户都可以从中获取预配置的账号。",
-    "Provision an account for every user" : "为每个用户设置一个账号",
+    "Configuration for \"{provisioningDomain}\"" : "\"{provisioningDomain}\" 的配置",
     "General" : "常规",
-    "Email address" : "Email 地址",
+    "Provisioning domain" : "开通域名",
+    "Email address template" : "电子邮件地址模板",
     "IMAP" : "IMAP",
     "User" : "用户",
     "Host" : "主机",
@@ -252,8 +298,8 @@ OC.L10N.register(
     "SMTP" : "SMTP",
     "Sieve" : "Sieve",
     "Enable sieve integration" : "启用 sieve 集成",
-    "Apply and create/update for all users" : "为所有用户应用并 创建 / 更新",
-    "Disable and un-provision existing accounts" : "禁用和取消设置现有账号",
+    "Save Config" : "保存配置",
+    "Unprovision & Delete Config" : "取消开通 & 删除配置",
     "With the settings above, the app will create account settings in the following way:" : "使用上述设置，该应用将通过以下方式创建账号设置：",
     "Keyboard shortcut" : "键盘快捷键",
     "Keyboard shortcuts" : "键盘快捷方式",
