@@ -7,10 +7,15 @@ OC.L10N.register(
     "Embedded message %s" : "內嵌郵件 %s",
     "Important mail" : "重要郵件",
     "Unread mail" : "未讀郵件",
+    "Important" : "重要",
+    "Work" : "業務",
+    "Personal" : "個人",
+    "To Do" : "待辦",
+    "Later" : "稍後",
     "Mails" : "郵件",
     "Mail" : "郵件",
     "💌 A mail app for Nextcloud" : "Nextcloud 的郵件應用程式",
-    "**💌 A mail app for Nextcloud**\n\n- **🚀 Integration with other Nextcloud apps!** Currently Contacts, Calendar & Files – more to come.\n- **📥 Multiple mail accounts!** Personal and company account? No problem, and a nice unified inbox. Connect any IMAP account.\n- **🔒 Send & receive encrypted mails!** Using the great [Mailvelope](https://mailvelope.com) browser extension.\n- **🙈 We’re not reinventing the wheel!** Based on the great [Horde](http://horde.org) libraries.\n- **📬 Want to host your own mail server?** We don’t have to reimplement this as you could set up [Mail-in-a-Box](https://mailinabox.email)!" : "**💌 Nextcloud 的郵件應用程式**\n\n- **🚀 與其他 Nextcloud 應用程式整合！** 目前有聯絡人、日曆與檔案 – 還會有更多。\n- **📥 多組郵件賬號！** 私人與公司賬號？沒問題，而且有很好的統一收件匣。可連線到任何 IMAP 賬號。\n- **🔒 傳送與接收加密電子郵件！** 使用超棒的 [Mailvelope](https://mailvelope.com) 瀏覽器擴充套件。\n- **🙈 我們並未重新發明輪子！** 以超棒的 [Horde](http://horde.org) 函式庫為基礎。\n- **📬 想要自架郵件伺服器嗎？** 我們不用重新實作此動作，因為您可以設定 [Mail-in-a-Box](https://mailinabox.email)！",
+    "**💌 A mail app for Nextcloud**\n\n- **🚀 Integration with other Nextcloud apps!** Currently Contacts, Calendar & Files – more to come.\n- **📥 Multiple mail accounts!** Personal and company account? No problem, and a nice unified inbox. Connect any IMAP account.\n- **🔒 Send & receive encrypted mails!** Using the great [Mailvelope](https://mailvelope.com) browser extension.\n- **🙈 We’re not reinventing the wheel!** Based on the great [Horde](https://horde.org) libraries.\n- **📬 Want to host your own mail server?** We don’t have to reimplement this as you could set up [Mail-in-a-Box](https://mailinabox.email)!" : "**💌 Nextcloud 的郵件應用程式**\n\n- **🚀 與其他 Nextcloud 應用程式整合！** 目前有聯絡人、日曆與檔案 – 還會有更多。\n- **📥 多組郵件賬號！** 私人與公司賬號？沒問題，而且有很好的統一收件匣。可連線到任何 IMAP 賬號。\n- **🔒 傳送與接收加密電子郵件！** 使用超棒的 [Mailvelope]（https://mailvelope.com）瀏覽器擴充套件。\n- **🙈 我們並未重新發明輪子！** 以超棒的 [Horde]（https://horde.org）函式庫為基礎。\n- **📬 想要自架郵件伺服器嗎？** 我們不用重新實作此動作，因為您可以設定 [Mail-in-a-Box]（https://mailinabox.email）！",
     "Drafts are saved in:" : "草稿儲存於：",
     "Sent messages are saved in:" : "已傳送的郵件儲存於：",
     "Deleted messages are moved in:" : "已刪除的郵件移動至：",
@@ -39,23 +44,26 @@ OC.L10N.register(
     "Account settings" : "賬號設定",
     "Change name" : "更改名稱",
     "Signature" : "簽名",
-    "A signature is added to the text of new messages and replies." : "對新信件與回覆信件內容已新增一個簽名檔",
-    "Writing mode" : "寫作模式",
-    "Preferred writing mode for new messages and replies." : "新訊息和回覆的首選編寫方式。",
+    "A signature is added to the text of new messages and replies." : "對新信件與回覆信件內容已附加一個簽名檔",
+    "Writing mode" : "書寫模式",
+    "Preferred writing mode for new messages and replies." : "新訊息和回覆的首選書寫模式。",
     "Default folders" : "默認資料夾",
     "The folders to use for drafts, sent messages and deleted messages." : "用於存儲草稿，已發送郵件和已刪除郵件的資料夾。",
     "Mail server" : "郵件伺服器",
     "Sieve filter server" : "Sieve 過濾伺服器",
     "Sieve filter rules" : "Sieve 過濾規則",
-    "Trusted senders" : "可信的寄件人",
+    "Trusted senders" : "受信任的寄件人",
     "Add alias" : "新增別名",
     "Add mail account" : "新增郵件賬號",
     "Use Gravatar and favicon avatars" : "使用個人化大頭貼與網站圖示",
     "Register as application for mail links" : "註冊為郵件連結的處理應用程式",
     "Show keyboard shortcuts" : "顯示鍵盤快捷鍵",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "允許應用程式蒐集關於您互動的資料。以此資料為基礎，應用程式將會適應您的偏好設定。資料將只會儲存在本機。",
+    "Put my text to the bottom of a reply instead of on top of it." : "將我的文字放在回覆的底部而不是頂部。",
+    "Automatically classify importance of new email" : "自動分類新郵件的重要性",
+    "Could not update preference" : "無法更新偏愛",
     "From" : "從",
-    "Select account" : "選取賬號",
+    "Select account" : "選擇賬號",
     "To" : "至",
     "Contact or email address …" : "聯絡人或電郵地址 ...",
     "+ Cc/Bcc" : "+ 副本/密件副本",
@@ -67,7 +75,7 @@ OC.L10N.register(
     "This message came from a noreply address so your reply will probably not be read." : "此郵件來自 noreply 地址，所以您的回覆可能不會被閱讀。",
     "The following recipients do not have a PGP key: {recipients}." : "以下收件者沒有 PGP 金鑰：{recipients}。",
     "Write message …" : "編寫郵件 ...",
-    "Can not save draft because this account does not have a drafts mailbox configured." : "無法儲存草稿，因為此賬號未設定草稿信箱。",
+    "Cannot save draft because this account does not have a drafts mailbox configured." : "無法儲存草稿，因為此賬號未設定草稿信箱。",
     "Saving draft …" : "正在儲存草稿 …",
     "Draft saved" : "草稿已儲存",
     "Upload attachment" : "已上傳附件",
@@ -81,6 +89,8 @@ OC.L10N.register(
     "Error sending your message" : "傳送您的郵件時發生錯誤",
     "Go back" : "返回",
     "Retry" : "重試",
+    "Warning sending your message" : "傳送您的郵件時發生警告",
+    "Send anyway" : "仍然傳送",
     "Message sent!" : "信件已寄出",
     "Write another message" : "編寫其他郵件",
     "Add share link from {productName} Files" : "從 {productName} 檔案新增分享連結",
@@ -89,6 +99,7 @@ OC.L10N.register(
     "Send unencrypted" : "傳送未加密的",
     "Message {id} could not be found" : "找不到郵件 {id}",
     "No sent mailbox configured. Please pick one in the account settings." : "未設定寄件備份信箱。請在賬號設定中選取。",
+    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "您正在嘗試發送給“收件人”和/或“抄送”中的許多收件人。考慮使用密件抄送（Bcc）隱藏收件人地址。",
     "Uploading {percent}% …" : "正在上傳 {percent}%……",
     "Choose a file to add as attachment" : "選擇要作為附件的檔案",
     "Choose a file to share as a link" : "選擇要作為連結分享的檔案",
@@ -100,19 +111,33 @@ OC.L10N.register(
     "No messages in this mailbox" : "此信箱中沒有郵件",
     "No messages" : "沒有郵件",
     "Draft: " : "草稿：",
+    "Mark unimportant" : "標記為不重要",
+    "Mark important" : "標記為重要",
+    "Mark unfavorite" : "取消標記我的最愛",
+    "Mark favorite" : "標記為我的最愛",
+    "Mark unread" : "標記為未讀",
+    "Mark read" : "標記為已讀",
+    "Mark not spam" : "標記為非垃圾郵件",
+    "Mark as spam" : "標記為垃圾郵件",
+    "Unselect" : "取消選擇",
+    "Select" : "選擇",
+    "Edit tags" : "編輯標籤",
+    "Move thread" : "移動主題",
+    "Edit as new message" : "以新郵件的方式編輯",
+    "Delete thread" : "刪除主題",
     "Blind copy recipients only" : "僅密件副本收件者",
-    "Load more" : "載入更多",
     "No trash mailbox configured" : "未設定垃圾信箱",
     "Could not delete message" : "無法刪除郵件",
+    "Load more" : "載入更多",
     "_Mark {number} unread_::_Mark {number} unread_" : ["將 {number} 標記為未讀"],
     "_Mark {number} read_::_Mark {number} read_" : ["將 {number} 標記為已讀"],
     "_Unfavorite {number}_::_Unfavorite {number}_" : ["取消我的最愛 {number}"],
     "_Favorite {number}_::_Favorite {number}_" : ["我的最愛 {number}"],
-    "_Unselect {number}_::_Unselect {number}_" : ["取消選取 {number}"],
-    "_Move {number}_::_Move {number}_" : ["移動 {number}"],
+    "_Unselect {number}_::_Unselect {number}_" : ["取消選擇 {number}"],
+    "_Move {number} thread_::_Move {number} threads_" : ["移動 {number} 主題"],
     "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["轉發 {number} 作為附件"],
-    "_Delete {number}_::_Delete {number}_" : ["刪除 {number}"],
-    "Report this bug" : "回報此錯誤 ",
+    "_Delete {number} thread_::_Delete {number} threads_" : ["刪除 {number} 主題"],
+    "Report this bug" : "舉報此錯誤 ",
     "Could not open mailbox" : "無法開啟信箱",
     "Loading messages" : "正在載入郵件",
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "正在索引您的郵件。對於較大的信箱來說，這可能需要較長的時間。",
@@ -128,27 +153,17 @@ OC.L10N.register(
     "Notify the sender" : "通知寄件人",
     "You sent a read confirmation to the sender of this message." : "你已將讀取回條傳送給此郵件的寄件人。",
     "Could not send mdn" : "無法傳送 mdn",
+    "Reply" : "回覆",
     "Reply to sender only" : "僅回覆寄件人",
     "Forward" : "轉寄",
-    "Edit as new message" : "以新郵件的方式編輯",
-    "Mark unimportant" : "標記為不重要",
-    "Mark important" : "標記為重要",
-    "Mark unfavorite" : "取消標記我的最愛",
-    "Mark favorite" : "標記為我的最愛",
-    "Mark unread" : "標記為未讀",
-    "Mark read" : "標記為已讀",
-    "Mark not spam" : "標記為非垃圾郵件",
-    "Mark as spam" : "標記為垃圾郵件",
-    "Unselect" : "取消選取",
-    "Select" : "選取",
-    "Move" : "移動",
+    "Move message" : "移動訊息",
     "View source" : "檢視原始碼",
     "Download thread data for debugging" : "下載郵件串的資料以供除錯",
-    "Delete" : "刪除",
+    "Delete message" : "刪除訊息",
     "Message source" : "郵件原始碼",
     "Message body" : "郵件正文",
     "Attachments" : "附件",
-    "Import into calendar" : "匯入到日曆",
+    "Import into calendar" : "導入到日曆",
     "Download attachment" : "下載附件",
     "Save to Files" : "儲存至雲端檔案",
     "Unnamed" : "未命名",
@@ -159,11 +174,16 @@ OC.L10N.register(
     "Choose a folder to store the attachments in" : "選擇一個資料夾來存放附件",
     "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "此郵件使用 PGP 加密。安裝 Mailvelope 來解密。",
     "The images have been blocked to protect your privacy." : "為維護您的隱私，圖片將不會被載入。",
+    "Show" : "顯示",
+    "Show images temporarily" : "暫時顯示圖像",
     "Always show images from {sender}" : "一律顯示來自 {sender} 的圖像",
     "Always show images from {domain}" : "一律顯示來自 {domain} 的圖像",
     "Message frame" : "郵件框",
     "Quoted text" : "引用文字",
+    "Move" : "移動",
     "Moving" : "正在移動",
+    "Moving thread" : "移動主題",
+    "Moving message" : "移動訊息",
     "New message" : "新郵件",
     "Settings" : "設定",
     "Quota" : "用量",
@@ -182,13 +202,13 @@ OC.L10N.register(
     "Cancel" : "取消",
     "Show all subscribed mailboxes" : "顯示所有已訂閱的信箱",
     "Show all mailboxes" : "顯示所有信箱",
-    "Collapse mailboxes" : "折疊信箱",
+    "Collapse mailboxes" : "收合信箱",
     "Mark all as read" : "全部標記為已讀",
     "Mark all messages of this mailbox as read" : "將此信箱所有的郵件標記為已讀",
     "Add submailbox" : "新增子信箱",
     "Edit name" : "編輯名稱",
-    "Clear cache" : "清除快取",
-    "Clear locally cached data, in case there are issues with synchronization." : "如果遇到同步問題，請清除本機快取資料。",
+    "Clear cache" : "清除緩存",
+    "Clear locally cached data, in case there are issues with synchronization." : "如果遇到同步問題，請清除近端緩存資料。",
     "Subscribed" : "已訂閱",
     "Sync in background" : "背景同步",
     "Delete mailbox" : "刪除信箱",
@@ -201,13 +221,19 @@ OC.L10N.register(
     "Attachments were not copied. Please add them manually." : "未複製附件。請手動新增它們。",
     "Could not load your draft" : "無法載入您的草稿",
     "Could not load original message" : "無法載入原始郵件",
-    "No message selected" : "未選取郵件",
+    "No message selected" : "未選擇郵件",
+    "Contacts with this address" : "具有此地址的聯絡人",
+    "Add to Contact" : "新增聯絡人",
+    "New Contact" : "新聯絡人",
+    "Contact name …" : "聯絡人名稱 ...",
+    "Add" : "新增",
     "Disabled" : "停用",
     "Enabled" : "啟用",
     "Sieve Host" : "Sieve 主機",
     "Sieve Security" : "Sieve 安全性",
     "Sieve Port" : "Sieve 連接埠",
-    "Sieve Credentials" : "Sieve 身份驗證",
+    "Sieve Credentials" : "Sieve 身分驗證",
+    "IMAP Credentials" : "IMAP 身分驗證",
     "Custom" : "自訂",
     "Sieve User" : "Sieve 賬戶",
     "Sieve Password" : "Sieve 密碼",
@@ -215,10 +241,14 @@ OC.L10N.register(
     "Save sieve settings" : "保存 Sieve 設置",
     "Save sieve script" : "保存 Sieve 腳本語言（script）",
     "Signature …" : "簽名……",
+    "Place signature above quoted text" : "將簽名置於引用文字上方",
     "Save signature" : "儲存簽名",
-    "Could not load your message thread" : "無法載入您的郵件串",
-    "Reply" : "回覆",
+    "Delete" : "刪除",
     "Remove" : "移除",
+    "Add tag" : "添加標籤",
+    "Saving tag …" : "標籤儲存中 ...",
+    "An error occurred, unable to create the tag." : "發生錯誤，無法建立標籤。",
+    "Could not load your message thread" : "無法載入您的郵件串",
     "No senders are trusted at the moment." : "當前沒有發件人是受信任的",
     "Could not remove trusted sender {sender}" : "無法刪除受信任的發件人 {sender}",
     "individual" : "個人",
@@ -234,24 +264,42 @@ OC.L10N.register(
     "Train from {depStation} to {arrStation}" : "從 {depStation} 至 {arrStation} 的火車",
     "Mail app" : "郵件應用程式",
     "The mail app allows users to read mails on their IMAP accounts." : "郵件應用程序使用戶可以閱讀其 IMAP 賬戶上的郵件。",
-    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "您可以在此找到全站台的設定。在應用程式本身（左下角）可以找到使用者設定。",
+    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "您可以在此找到全站台的設定。在應用程式本身（左下角）可以找到用戶設定。",
+    "A provisioning configuration will provision all accounts with a matching email address." : "供應配置將為所有帳戶供應匹配的電郵地址。",
+    "Using the wildcard (*) in the provisioning domain field will create a configuration that applies to all users, provided they do not match another configuration." : "在配置網域字段中使用通配符（*）將創建一個適用於所有用戶的配置，前提是它與其他配置不匹配。",
+    "The provisioning mechanism will prioritise specific domain configurations over the wildcard domain configuration." : "供應機制將特定網域配置優先於通配符網域配置。",
+    "Should a new matching configuration be found after the user was already provisioned with another configuration, the new configuration will take precedence and the user will be reprovisioned with the configuration." : "如果在為用戶提供另一個配置後發現新的匹配配置，則新配置將優先，用戶將重新提供該配置。",
+    "There can only be one configuration per domain and only one wildcard domain configuration." : "每個網域只能有一種配置，並且只能有一種通配符網域配置。",
+    "These settings can be used in conjunction with each other." : "這些設置可以相互結合使用。",
+    "If you only want to provision one domain for all users, use the wildcard (*)." : "如果您只想為所有用戶配置一個域，請使用通配符（*）。",
+    "Add new config" : "添加新配置",
+    "Provision all accounts" : "配置所有賬戶",
+    "Successfully updated config for \"{domain}\"" : "已成功更新 “{domain}” 的配置",
+    "Error saving config" : "存儲配置時發生錯誤",
+    "Saved config for \"{domain}\"" : "已成功保存 “{domain}” 的配置",
+    "Could not save provisioning setting" : "無法保存配置設置",
+    "There was an error when provisioning accounts." : "配置賬戶時出錯。",
+    "Successfully deleted and deprovisioned accounts for \"{domain}\"" : "已成功刪除和取消配置 “{domain}” 的賬戶",
+    "Error when deleting and deprovisioning accounts for \"{domain}\"" : "刪除和取消配置“{domain}”的賬戶時出錯",
+    "_Successfully provisioned {count} account._::_Successfully provisioned {count} accounts._" : ["成功配置 {count} 個賬戶。"],
+    "Domain Match: {provisioningDomain}" : "網域匹配：{provisioningDomain}",
     "Email: {email}" : "電子郵件：{email}",
-    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP：{user} 在 {host}:{port}（{ssl} 加密）",
-    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP：{user} 在 {host}:{port}（{ssl} 加密）",
-    "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "Sieve：{user} 在 {host}:{port}（{ssl} 加密）",
-    "You can configure a template for account settings, from which all users will get an account provisioned from." : "您可以為賬號設定建立範本，所有使用者都可以從其中取得預先設定好的賬號。",
-    "Provision an account for every user" : "為每個使用者設定一個賬號",
+    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP：{user} 在 {host}：{port}（{ssl} 加密）",
+    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP：{user} 在 {host}：{port}（{ssl} 加密）",
+    "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "Sieve：{user} 在 {host}：{port}（{ssl} 加密）",
+    "Configuration for \"{provisioningDomain}\"" : "“{provisioningDomain}” 的配置",
     "General" : "一般",
-    "Email address" : "電郵地址",
+    "Provisioning domain" : "配置網域",
+    "Email address template" : "電郵地址模板",
     "IMAP" : "IMAP",
-    "User" : "使用者",
+    "User" : "用戶",
     "Host" : "主機",
     "Port" : "連接埠",
     "SMTP" : "SMTP",
     "Sieve" : "Sieve",
     "Enable sieve integration" : "啟用 Sieve 整合",
-    "Apply and create/update for all users" : "為所有使用者套用並建立／更新",
-    "Disable and un-provision existing accounts" : "停用並取消設定現有賬號",
+    "Save Config" : "保存配置",
+    "Unprovision & Delete Config" : "取消配置和刪除配置",
     "With the settings above, the app will create account settings in the following way:" : "使用上述設定，應用程式將會以下列方式建立賬號：",
     "Keyboard shortcut" : "鍵盤快捷鍵",
     "Keyboard shortcuts" : "鍵盤快捷鍵",
@@ -274,7 +322,7 @@ OC.L10N.register(
     "Inbox" : "收件匣",
     "Junk" : "垃圾郵件",
     "Sent" : "發送",
-    "Trash" : "回收筒",
+    "Trash" : "回收桶",
     "Error while sharing file" : "分享檔案時發生錯誤",
     "{from}\n{subject}" : "{from}\n{subject}",
     "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n 則新信件\n來自 {from}"],
