@@ -7,10 +7,15 @@ OC.L10N.register(
     "Embedded message %s" : "內嵌郵件 %s",
     "Important mail" : "重要郵件",
     "Unread mail" : "未讀郵件",
+    "Important" : "重要",
+    "Work" : "工作",
+    "Personal" : "個人",
+    "To Do" : "待辦",
+    "Later" : "稍後",
     "Mails" : "郵件",
     "Mail" : "電子郵件",
     "💌 A mail app for Nextcloud" : "Nextcloud 的郵件應用程式",
-    "**💌 A mail app for Nextcloud**\n\n- **🚀 Integration with other Nextcloud apps!** Currently Contacts, Calendar & Files – more to come.\n- **📥 Multiple mail accounts!** Personal and company account? No problem, and a nice unified inbox. Connect any IMAP account.\n- **🔒 Send & receive encrypted mails!** Using the great [Mailvelope](https://mailvelope.com) browser extension.\n- **🙈 We’re not reinventing the wheel!** Based on the great [Horde](http://horde.org) libraries.\n- **📬 Want to host your own mail server?** We don’t have to reimplement this as you could set up [Mail-in-a-Box](https://mailinabox.email)!" : "**💌 Nextcloud 的郵件應用程式**\n\n- **🚀 與其他 Nextcloud 應用程式整合！** 目前有聯絡人、日曆與檔案 – 還會有更多。\n- **📥 多組郵件帳號！** 私人與公司帳號？沒問題，而且有很好的統一收件匣。可連線到任何 IMAP 帳號。\n- **🔒 傳送與接收加密電子郵件！** 使用超棒的 [Mailvelope](https://mailvelope.com) 瀏覽器擴充套件。\n- **🙈 我們並未重新發明輪子！** 以超棒的 [Horde](http://horde.org) 函式庫為基礎。\n- **📬 想要自架郵件伺服器嗎？** 我們不用重新實作此動作，因為您可以設定 [Mail-in-a-Box](https://mailinabox.email)！",
+    "**💌 A mail app for Nextcloud**\n\n- **🚀 Integration with other Nextcloud apps!** Currently Contacts, Calendar & Files – more to come.\n- **📥 Multiple mail accounts!** Personal and company account? No problem, and a nice unified inbox. Connect any IMAP account.\n- **🔒 Send & receive encrypted mails!** Using the great [Mailvelope](https://mailvelope.com) browser extension.\n- **🙈 We’re not reinventing the wheel!** Based on the great [Horde](https://horde.org) libraries.\n- **📬 Want to host your own mail server?** We don’t have to reimplement this as you could set up [Mail-in-a-Box](https://mailinabox.email)!" : "**💌 Nextcloud 的郵件應用程式**\n\n- **🚀 與其他 Nextcloud 應用程式整合！** 目前有聯絡人、日曆與檔案 – 還會有更多。\n- **📥 多組郵件帳號！** 私人與公司帳號？沒問題，而且有很好的統一收件匣。可連線到任何 IMAP 帳號。\n- **🔒 傳送與接收加密電子郵件！** 使用超棒的 [Mailvelope](https://mailvelope.com) 瀏覽器擴充套件。\n- **🙈 我們並未重新發明輪子！** 以超棒的 [Horde](https://horde.org) 函式庫為基礎。\n- **📬 想要自架郵件伺服器嗎？** 我們不用重新實作此動作，因為您可以設定 [Mail-in-a-Box](https://mailinabox.email)！",
     "Drafts are saved in:" : "草稿儲存於：",
     "Sent messages are saved in:" : "已傳送的郵件儲存於：",
     "Deleted messages are moved in:" : "已刪除的郵件移動至：",
@@ -55,6 +60,8 @@ OC.L10N.register(
     "Show keyboard shortcuts" : "顯示鍵盤快捷鍵",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "允許應用程式蒐集關於您互動的資料。以此資料為基礎，應用程式將會適應您的偏好設定。資料將只會儲存在本機。",
     "Put my text to the bottom of a reply instead of on top of it." : "將我的文字放在回覆的底部而非頂部。",
+    "Automatically classify importance of new email" : "自動分類新電子郵件的重要性",
+    "Could not update preference" : "無法更新偏好設定",
     "From" : "從",
     "Select account" : "選取帳號",
     "To" : "至",
@@ -68,7 +75,7 @@ OC.L10N.register(
     "This message came from a noreply address so your reply will probably not be read." : "此郵件來自 noreply 地址，所以您的回覆可能不會被閱讀。",
     "The following recipients do not have a PGP key: {recipients}." : "以下收件者沒有 PGP 金鑰：{recipients}。",
     "Write message …" : "編寫郵件……",
-    "Can not save draft because this account does not have a drafts mailbox configured." : "無法儲存草稿，因為此帳號未設定草稿信箱。",
+    "Cannot save draft because this account does not have a drafts mailbox configured." : "無法儲存草稿，因為此帳號未設定草稿信箱。",
     "Saving draft …" : "正在儲存草稿……",
     "Draft saved" : "草稿已儲存",
     "Upload attachment" : "已上傳附件",
@@ -82,6 +89,8 @@ OC.L10N.register(
     "Error sending your message" : "傳送您的郵件時發生錯誤",
     "Go back" : "返回",
     "Retry" : "重試",
+    "Warning sending your message" : "在傳送您的郵件時警告",
+    "Send anyway" : "無論無何都要傳送",
     "Message sent!" : "信件已寄出",
     "Write another message" : "編寫其他郵件",
     "Add share link from {productName} Files" : "從 {productName} 檔案新增分享連結",
@@ -90,6 +99,7 @@ OC.L10N.register(
     "Send unencrypted" : "傳送未加密的",
     "Message {id} could not be found" : "找不到郵件 {id}",
     "No sent mailbox configured. Please pick one in the account settings." : "未設定寄件備份信箱。請在帳號設定中選取。",
+    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "您正試圖傳送郵件給「收件者」及／或「副本」中的許多人。請考慮使用「密件副本」來隱藏收件者地址。",
     "Uploading {percent}% …" : "正在上傳 {percent}%……",
     "Choose a file to add as attachment" : "選擇要作為附件的檔案",
     "Choose a file to share as a link" : "選擇要作為連結分享的檔案",
@@ -101,18 +111,32 @@ OC.L10N.register(
     "No messages in this mailbox" : "此信箱中沒有郵件",
     "No messages" : "沒有郵件",
     "Draft: " : "草稿：",
+    "Mark unimportant" : "標記為不重要",
+    "Mark important" : "標記為重要",
+    "Mark unfavorite" : "取消標記我的最愛",
+    "Mark favorite" : "標記為我的最愛",
+    "Mark unread" : "標記為未讀",
+    "Mark read" : "標記為已讀",
+    "Mark not spam" : "標記為非垃圾郵件",
+    "Mark as spam" : "標記為垃圾郵件",
+    "Unselect" : "取消選取",
+    "Select" : "選取",
+    "Edit tags" : "編輯標籤",
+    "Move thread" : "移動討論串",
+    "Edit as new message" : "以新郵件的方式編輯",
+    "Delete thread" : "刪除討論串",
     "Blind copy recipients only" : "僅密件副本收件者",
-    "Load more" : "載入更多",
     "No trash mailbox configured" : "未設定垃圾信箱",
     "Could not delete message" : "無法刪除郵件",
+    "Load more" : "載入更多",
     "_Mark {number} unread_::_Mark {number} unread_" : ["將 {number} 標記為未讀"],
     "_Mark {number} read_::_Mark {number} read_" : ["將 {number} 標記為已讀"],
     "_Unfavorite {number}_::_Unfavorite {number}_" : ["取消我的最愛 {number}"],
     "_Favorite {number}_::_Favorite {number}_" : ["我的最愛 {number}"],
     "_Unselect {number}_::_Unselect {number}_" : ["取消選取 {number}"],
-    "_Move {number}_::_Move {number}_" : ["移動 {number}"],
+    "_Move {number} thread_::_Move {number} threads_" : ["移動 {number} 個討論串"],
     "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["轉寄 {number} 作為附件"],
-    "_Delete {number}_::_Delete {number}_" : ["刪除 {number}"],
+    "_Delete {number} thread_::_Delete {number} threads_" : ["刪除 {number} 個討論串"],
     "Report this bug" : "回報此臭蟲",
     "Could not open mailbox" : "無法開啟信箱",
     "Loading messages" : "正在載入郵件",
@@ -129,23 +153,13 @@ OC.L10N.register(
     "Notify the sender" : "通知寄件者",
     "You sent a read confirmation to the sender of this message." : "你已將讀取回條傳送給此郵件的寄件者。",
     "Could not send mdn" : "無法傳送 mdn",
+    "Reply" : "回覆",
     "Reply to sender only" : "僅回覆寄件者",
     "Forward" : "轉寄",
-    "Edit as new message" : "以新郵件的方式編輯",
-    "Mark unimportant" : "標記為不重要",
-    "Mark important" : "標記為重要",
-    "Mark unfavorite" : "取消標記我的最愛",
-    "Mark favorite" : "標記為我的最愛",
-    "Mark unread" : "標記為未讀",
-    "Mark read" : "標記為已讀",
-    "Mark not spam" : "標記為非垃圾郵件",
-    "Mark as spam" : "標記為垃圾郵件",
-    "Unselect" : "取消選取",
-    "Select" : "選取",
-    "Move" : "移動",
+    "Move message" : "移動訊息",
     "View source" : "檢視原始碼",
     "Download thread data for debugging" : "下載郵件串的資料以供除錯",
-    "Delete" : "刪除",
+    "Delete message" : "刪除訊息",
     "Message source" : "郵件原始碼",
     "Message body" : "郵件正文",
     "Attachments" : "附件",
@@ -160,11 +174,16 @@ OC.L10N.register(
     "Choose a folder to store the attachments in" : "選擇一個資料夾來存放附件",
     "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "此郵件使用 PGP 加密。安裝 Mailvelope 來解密。",
     "The images have been blocked to protect your privacy." : "為維護您的隱私，圖片將不會被載入。",
+    "Show" : "顯示",
+    "Show images temporarily" : "暫時顯示圖片",
     "Always show images from {sender}" : "一律顯示來自 {sender} 的圖片",
     "Always show images from {domain}" : "一律顯示來自 {domain} 的圖片",
     "Message frame" : "郵件框",
     "Quoted text" : "引用文字",
+    "Move" : "移動",
     "Moving" : "正在移動",
+    "Moving thread" : "正在移動討論串",
+    "Moving message" : "正在移動訊息",
     "New message" : "新郵件",
     "Settings" : "設定",
     "Quota" : "用量",
@@ -203,6 +222,11 @@ OC.L10N.register(
     "Could not load your draft" : "無法載入您的草稿",
     "Could not load original message" : "無法載入原始郵件",
     "No message selected" : "未選取郵件",
+    "Contacts with this address" : "有此地址的聯絡人",
+    "Add to Contact" : "新增至聯絡人",
+    "New Contact" : "新聯絡人",
+    "Contact name …" : "聯絡人名稱……",
+    "Add" : "新增",
     "Disabled" : "已停用",
     "Enabled" : "已啟用",
     "Sieve Host" : "過濾主機",
@@ -217,10 +241,14 @@ OC.L10N.register(
     "Save sieve settings" : "儲存過濾設定",
     "Save sieve script" : "儲存過濾指令稿",
     "Signature …" : "簽名……",
+    "Place signature above quoted text" : "將簽名置於引用文字上方",
     "Save signature" : "儲存簽名",
-    "Could not load your message thread" : "無法載入您的郵件串",
-    "Reply" : "回覆",
+    "Delete" : "刪除",
     "Remove" : "移除",
+    "Add tag" : "新增標籤",
+    "Saving tag …" : "正在儲存標籤……",
+    "An error occurred, unable to create the tag." : "遇到錯誤，無法建立標籤。",
+    "Could not load your message thread" : "無法載入您的郵件串",
     "No senders are trusted at the moment." : "目前沒有寄件者受到信任。",
     "Could not remove trusted sender {sender}" : "無法移除受信任的寄件者 {sender}",
     "individual" : "個人",
@@ -237,14 +265,32 @@ OC.L10N.register(
     "Mail app" : "郵件應用程式",
     "The mail app allows users to read mails on their IMAP accounts." : "郵件應用程式允許使用者閱讀在他們 IMAP 帳號上的郵件。",
     "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "您可以在此找到全站台的設定。在應用程式本身（左下角）可以找到使用者設定。",
+    "A provisioning configuration will provision all accounts with a matching email address." : "預備設定將會為所有符合特定電子郵件地址的帳號提供。",
+    "Using the wildcard (*) in the provisioning domain field will create a configuration that applies to all users, provided they do not match another configuration." : "在預備網域欄位中使用萬用字元 (*) 將會建立適用於所有使用者的設定，前提是這些使用者與其他設定不相符。",
+    "The provisioning mechanism will prioritise specific domain configurations over the wildcard domain configuration." : "預備機制將優先於特定的網域設定，最後才是萬用字元網域設定。",
+    "Should a new matching configuration be found after the user was already provisioned with another configuration, the new configuration will take precedence and the user will be reprovisioned with the configuration." : "如果使用者已被提供另一個設定後，又發現新的符合的設定，那麼新設定優先，使用者將會重新使用該設定。",
+    "There can only be one configuration per domain and only one wildcard domain configuration." : "每個網域只能有一個設定，且僅能有一個萬用字元網域設定。",
+    "These settings can be used in conjunction with each other." : "這些設定可以相互結合使用。",
+    "If you only want to provision one domain for all users, use the wildcard (*)." : "如果您只想為所有使用者預備一個網域，請使用萬用字元 (*)。",
+    "Add new config" : "加入新設定",
+    "Provision all accounts" : "預備所有帳號",
+    "Successfully updated config for \"{domain}\"" : "成功為「{domain}」更新設定",
+    "Error saving config" : "儲存設定時發生錯誤",
+    "Saved config for \"{domain}\"" : "已為「{domain}」儲存設定",
+    "Could not save provisioning setting" : "無法儲存預備設定",
+    "There was an error when provisioning accounts." : "設定帳號時發生錯誤。",
+    "Successfully deleted and deprovisioned accounts for \"{domain}\"" : "成功刪除並取消設定了「{domain}」的帳號",
+    "Error when deleting and deprovisioning accounts for \"{domain}\"" : "刪除並取消設定「{domain}」的帳號時發生錯誤",
+    "_Successfully provisioned {count} account._::_Successfully provisioned {count} accounts._" : ["成功設定 {count} 個帳號。"],
+    "Domain Match: {provisioningDomain}" : "網域符合：{provisioningDomain}",
     "Email: {email}" : "電子郵件：{email}",
     "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP：{user} 在 {host}:{port}（{ssl} 加密）",
     "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP：{user} 在 {host}:{port}（{ssl} 加密）",
     "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "過濾：{user} 在 {host}:{port}（{ssl} 加密）",
-    "You can configure a template for account settings, from which all users will get an account provisioned from." : "您可以為帳號設定建立範本，所有使用者都可以從其中取得預先設定好的帳號。",
-    "Provision an account for every user" : "為每個使用者設定一個帳號",
+    "Configuration for \"{provisioningDomain}\"" : "「{provisioningDomain}」的設定",
     "General" : "一般",
-    "Email address" : "電子郵件地址",
+    "Provisioning domain" : "預備設定網域",
+    "Email address template" : "電子郵件地址範本",
     "IMAP" : "IMAP",
     "User" : "使用者",
     "Host" : "主機",
@@ -252,8 +298,8 @@ OC.L10N.register(
     "SMTP" : "SMTP",
     "Sieve" : "過濾",
     "Enable sieve integration" : "啟用過濾整合",
-    "Apply and create/update for all users" : "為所有使用者套用並建立／更新",
-    "Disable and un-provision existing accounts" : "停用並取消設定現有帳號",
+    "Save Config" : "儲存設定",
+    "Unprovision & Delete Config" : "取消設定與刪除設定",
     "With the settings above, the app will create account settings in the following way:" : "使用上述設定，應用程式將會以下列方式建立帳號：",
     "Keyboard shortcut" : "鍵盤快捷鍵",
     "Keyboard shortcuts" : "鍵盤快捷鍵",
