@@ -41,7 +41,6 @@ use OCA\Mail\Exception\ClientException;
 use OCA\Mail\Exception\ServiceException;
 use OCA\Mail\Http\AttachmentDownloadResponse;
 use OCA\Mail\Http\HtmlResponse;
-use OCA\Mail\Model\IMAPMessage;
 use OCA\Mail\Service\AccountService;
 use OCA\Mail\Service\ItineraryService;
 use OCP\AppFramework\Controller;
@@ -308,7 +307,7 @@ class MessagesController extends Controller {
 			return new JSONResponse([], Http::STATUS_FORBIDDEN);
 		}
 
-		return new JSONResponse($this->mailManager->getThread($account, $id));
+		return new JSONResponse($this->mailManager->getThread($account, $message->getThreadRootId()));
 	}
 
 	/**
@@ -649,6 +648,68 @@ class MessagesController extends Controller {
 		return new JSONResponse();
 	}
 
+	/**
+	 * @NoAdminRequired
+	 * @TrapError
+	 *
+	 * @param int $id
+	 * @param string $imapLabel
+	 *
+	 * @return JSONResponse
+	 *
+	 * @throws ClientException
+	 * @throws ServiceException
+	 */
+	public function setTag(int $id, string $imapLabel): JSONResponse {
+		try {
+			$message = $this->mailManager->getMessage($this->currentUserId, $id);
+			$mailbox = $this->mailManager->getMailbox($this->currentUserId, $message->getMailboxId());
+			$account = $this->accountService->find($this->currentUserId, $mailbox->getAccountId());
+		} catch (DoesNotExistException $e) {
+			return new JSONResponse([], Http::STATUS_FORBIDDEN);
+		}
+
+		try {
+			$tag = $this->mailManager->getTagByImapLabel($imapLabel, $this->currentUserId);
+		} catch (ClientException $e) {
+			return new JSONResponse([], Http::STATUS_FORBIDDEN);
+		}
+
+		$this->mailManager->tagMessage($account, $mailbox->getName(), $message, $tag, true);
+		return new JSONResponse($tag);
+	}
+
+	/**
+	 * @NoAdminRequired
+	 * @TrapError
+	 *
+	 * @param int $id
+	 * @param string $imapLabel
+	 *
+	 * @return JSONResponse
+	 *
+	 * @throws ClientException
+	 * @throws ServiceException
+	 */
+	public function removeTag(int $id, string $imapLabel): JSONResponse {
+		try {
+			$message = $this->mailManager->getMessage($this->currentUserId, $id);
+			$mailbox = $this->mailManager->getMailbox($this->currentUserId, $message->getMailboxId());
+			$account = $this->accountService->find($this->currentUserId, $mailbox->getAccountId());
+		} catch (DoesNotExistException $e) {
+			return new JSONResponse([], Http::STATUS_FORBIDDEN);
+		}
+
+		try {
+			$tag = $this->mailManager->getTagByImapLabel($imapLabel, $this->currentUserId);
+		} catch (ClientException $e) {
+			return new JSONResponse([], Http::STATUS_FORBIDDEN);
+		}
+
+		$this->mailManager->tagMessage($account, $mailbox->getName(), $message, $tag, false);
+		return new JSONResponse($tag);
+	}
+
 	/**
 	 * @NoAdminRequired
 	 * @TrapError
@@ -705,10 +766,10 @@ class MessagesController extends Controller {
 	}
 
 	/**
-	 * @param array $attachment
-	 *
 	 * Determines if the content of this attachment is an image
 	 *
+	 * @param array $attachment
+	 *
 	 * @return boolean
 	 */
 	private function attachmentIsImage(array $attachment): bool {
