@@ -15,7 +15,6 @@ declare(strict_types=1);
 namespace OCA\Mail\Db;
 
 use OCP\AppFramework\Db\DoesNotExistException;
-use OCP\AppFramework\Db\MultipleObjectsReturnedException;
 use OCP\AppFramework\Db\QBMapper;
 use OCP\DB\QueryBuilder\IQueryBuilder;
 use OCP\IDBConnection;
@@ -39,7 +38,6 @@ class AliasMapper extends QBMapper {
 	 *
 	 * @return Alias
 	 * @throws DoesNotExistException
-	 * @throws MultipleObjectsReturnedException
 	 */
 	public function find(int $aliasId, string $currentUserId): Alias {
 		$qb = $this->db->getQueryBuilder();
@@ -104,9 +102,11 @@ class AliasMapper extends QBMapper {
 		$result->closeCursor();
 
 		$qb2 = $this->db->getQueryBuilder();
-		$query = $qb2
-			->delete($this->getTableName())
-			->where($qb2->expr()->in('id', $qb2->createNamedParameter($ids, IQueryBuilder::PARAM_INT_ARRAY), IQueryBuilder::PARAM_INT_ARRAY));
-		$query->execute();
+		foreach (array_chunk($ids, 1000) as $chunk) {
+			$query = $qb2
+				->delete($this->getTableName())
+				->where($qb2->expr()->in('id', $qb2->createNamedParameter($chunk, IQueryBuilder::PARAM_INT_ARRAY), IQueryBuilder::PARAM_INT_ARRAY));
+			$query->execute();
+		}
 	}
 }
