@@ -65,6 +65,21 @@ class MailboxMapper extends QBMapper {
 		return $this->findEntities($select);
 	}
 
+	/**
+	 * @return \Generator<int>
+	 */
+	public function findAllIds(): \Generator {
+		$qb = $this->db->getQueryBuilder();
+		$qb->select('id')
+			->from($this->getTableName());
+
+		$cursor = $qb->execute();
+		while ($row = $cursor->fetch()) {
+			yield (int)$row['id'];
+		}
+		$cursor->closeCursor();
+	}
+
 	/**
 	 * @throws DoesNotExistException
 	 * @throws ServiceException
@@ -241,9 +256,34 @@ class MailboxMapper extends QBMapper {
 		$result->closeCursor();
 
 		$qb2 = $this->db->getQueryBuilder();
-		$query = $qb2
-			->delete($this->getTableName())
-			->where($qb2->expr()->in('id', $qb2->createNamedParameter($ids, IQueryBuilder::PARAM_INT_ARRAY), IQueryBuilder::PARAM_INT_ARRAY));
-		$query->execute();
+		foreach (array_chunk($ids, 1000) as $chunk) {
+			$query = $qb2
+				->delete($this->getTableName())
+				->where($qb2->expr()->in('id', $qb2->createNamedParameter($chunk, IQueryBuilder::PARAM_INT_ARRAY), IQueryBuilder::PARAM_INT_ARRAY));
+			$query->execute();
+		}
+	}
+
+	/**
+	 * Get all UIDS for mail_messages.flag_important = true
+	 *
+	 * @return int[]
+	 */
+	public function findFlaggedImportantUids(int $mailboxId) : array {
+		$qb = $this->db->getQueryBuilder();
+		$query = $qb->select('uid')
+				->from('mail_messages')
+				->where(
+					$qb->expr()->eq('mailbox_id', $qb->createNamedParameter($mailboxId)),
+					$qb->expr()->eq('flag_important', $qb->createNamedParameter(true, IQueryBuilder::PARAM_BOOL))
+				);
+
+		$cursor = $query->execute();
+		$uids = array_map(function (array $row) {
+			return (int)$row['uid'];
+		}, $cursor->fetchAll());
+		$cursor->closeCursor();
+
+		return $uids;
 	}
 }
