@@ -32,6 +32,8 @@ use OCA\Mail\IMAP\Threading\DatabaseMessage;
 use OCA\Mail\Service\Search\Flag;
 use OCA\Mail\Service\Search\FlagExpression;
 use OCA\Mail\Service\Search\SearchQuery;
+use OCA\Mail\Support\PerformanceLogger;
+use OCA\Mail\Support\PerformanceLoggerTask;
 use OCP\AppFramework\Db\DoesNotExistException;
 use OCP\AppFramework\Db\QBMapper;
 use OCP\AppFramework\Utility\ITimeFactory;
@@ -42,9 +44,11 @@ use RuntimeException;
 use function array_combine;
 use function array_keys;
 use function array_map;
+use function array_udiff;
 use function get_class;
 use function ltrim;
-use function mb_substr;
+use function mb_strcut;
+use function OCA\Mail\array_flat_map;
 
 /**
  * @template-extends QBMapper<Message>
@@ -54,10 +58,20 @@ class MessageMapper extends QBMapper {
 	/** @var ITimeFactory */
 	private $timeFactory;
 
+	/** @var TagMapper */
+	private $tagMapper;
+
+	/** @var PerformanceLogger */
+	private $performanceLogger;
+
 	public function __construct(IDBConnection $db,
-								ITimeFactory $timeFactory) {
+								ITimeFactory $timeFactory,
+								TagMapper $tagMapper,
+								PerformanceLogger $performanceLogger) {
 		parent::__construct($db, 'mail_messages');
 		$this->timeFactory = $timeFactory;
+		$this->tagMapper = $tagMapper;
+		$this->performanceLogger = $performanceLogger;
 	}
 
 	/**
@@ -93,7 +107,7 @@ class MessageMapper extends QBMapper {
 	public function findHighestUid(Mailbox $mailbox): ?int {
 		$query = $this->db->getQueryBuilder();
 
-		$query->select($query->createFunction('MAX(' . $query->getColumnName('uid') . ')'))
+		$query->select($query->func()->max('uid'))
 			->from($this->getTableName())
 			->where($query->expr()->eq('mailbox_id', $query->createNamedParameter($mailbox->getId())));
 
@@ -107,7 +121,7 @@ class MessageMapper extends QBMapper {
 		return $max;
 	}
 
-	public function findByUserId(string $uid, int $id): Message {
+	public function findByUserId(string $userId, int $id): Message {
 		$query = $this->db->getQueryBuilder();
 
 		$query->select('m.*')
@@ -115,11 +129,11 @@ class MessageMapper extends QBMapper {
 			->join('m', 'mail_mailboxes', 'mb', $query->expr()->eq('m.mailbox_id', 'mb.id', IQueryBuilder::PARAM_INT))
 			->join('m', 'mail_accounts', 'a', $query->expr()->eq('mb.account_id', 'a.id', IQueryBuilder::PARAM_INT))
 			->where(
-				$query->expr()->eq('a.user_id', $query->createNamedParameter($uid)),
+				$query->expr()->eq('a.user_id', $query->createNamedParameter($userId)),
 				$query->expr()->eq('m.id', $query->createNamedParameter($id, IQueryBuilder::PARAM_INT), IQueryBuilder::PARAM_INT)
 			);
 
-		$results = $this->findRecipients($this->findEntities($query));
+		$results = $this->findRelatedData($this->findEntities($query), $userId);
 		if (empty($results)) {
 			throw new DoesNotExistException("Message $id does not exist");
 		}
@@ -166,15 +180,10 @@ class MessageMapper extends QBMapper {
 				$query->expr()->in('id', $query->createParameter('ids'), IQueryBuilder::PARAM_INT_ARRAY)
 			);
 
-		$chunks = array_chunk($ids, 1000);
-
-		$results = [];
-		foreach ($chunks as $chunk) {
+		return array_flat_map(function (array $chunk) use ($query) {
 			$query->setParameter('ids', $chunk, IQueryBuilder::PARAM_INT_ARRAY);
-			$results[] = $this->findUids($query);
-		}
-
-		return array_merge(...$results);
+			return $this->findUids($query);
+		}, array_chunk($ids, 1000));
 	}
 
 	/**
@@ -237,7 +246,11 @@ class MessageMapper extends QBMapper {
 		$this->db->commit();
 	}
 
-	public function insertBulk(Message ...$messages): void {
+	/**
+	 * @param Message ...$messages
+	 * @return void
+	 */
+	public function insertBulk(Account $account, Message ...$messages): void {
 		$this->db->beginTransaction();
 
 		$qb1 = $this->db->getQueryBuilder();
@@ -311,25 +324,33 @@ class MessageMapper extends QBMapper {
 
 					$qb2->setParameter('message_id', $messageId, IQueryBuilder::PARAM_INT);
 					$qb2->setParameter('type', $type, IQueryBuilder::PARAM_INT);
-					$qb2->setParameter('label', mb_substr($recipient->getLabel(), 0, 255), IQueryBuilder::PARAM_STR);
+					$qb2->setParameter('label', mb_strcut($recipient->getLabel(), 0, 255), IQueryBuilder::PARAM_STR);
 					$qb2->setParameter('email', $recipient->getEmail(), IQueryBuilder::PARAM_STR);
 
 					$qb2->execute();
 				}
 			}
+			foreach ($message->getTags() as $tag) {
+				$this->tagMapper->tagMessage($tag, $message->getMessageId(), $account->getUserId());
+			}
 		}
 
 		$this->db->commit();
 	}
 
 	/**
-	 * @param Message ...$messages
-	 *
+	 * @param Account $account
+	 * @param bool $permflagsEnabled
+	 * @param Message[] $messages
 	 * @return Message[]
 	 */
-	public function updateBulk(Message ...$messages): array {
+	public function updateBulk(Account $account, bool $permflagsEnabled, Message ...$messages): array {
 		$this->db->beginTransaction();
 
+		$perf = $this->performanceLogger->start(
+			'partial sync ' . $account->getId() . ':' . $account->getName()
+		);
+
 		$query = $this->db->getQueryBuilder();
 		$query->update($this->getTableName())
 			->set('flag_answered', $query->createParameter('flag_answered'))
@@ -348,33 +369,94 @@ class MessageMapper extends QBMapper {
 				$query->expr()->eq('mailbox_id', $query->createParameter('mailbox_id'))
 			));
 
+		// get all tags before the loop and create a mapping [message_id => [tag,...]] but only if permflags are enabled
+		$tags = [];
+		if ($permflagsEnabled) {
+			$tags = $this->tagMapper->getAllTagsForMessages($messages, $account->getUserId());
+			$perf->step("Selected Tags for all messages");
+		}
+
 		foreach ($messages as $message) {
-			if (empty($message->getUpdatedFields())) {
-				// Micro optimization
-				continue;
+			if (empty($message->getUpdatedFields()) === false) {
+				// only run if there is anything to actually update
+				$query->setParameter('uid', $message->getUid(), IQueryBuilder::PARAM_INT);
+				$query->setParameter('mailbox_id', $message->getMailboxId(), IQueryBuilder::PARAM_INT);
+				$query->setParameter('flag_answered', $message->getFlagAnswered(), IQueryBuilder::PARAM_BOOL);
+				$query->setParameter('flag_deleted', $message->getFlagDeleted(), IQueryBuilder::PARAM_BOOL);
+				$query->setParameter('flag_draft', $message->getFlagDraft(), IQueryBuilder::PARAM_BOOL);
+				$query->setParameter('flag_flagged', $message->getFlagFlagged(), IQueryBuilder::PARAM_BOOL);
+				$query->setParameter('flag_seen', $message->getFlagSeen(), IQueryBuilder::PARAM_BOOL);
+				$query->setParameter('flag_forwarded', $message->getFlagForwarded(), IQueryBuilder::PARAM_BOOL);
+				$query->setParameter('flag_junk', $message->getFlagJunk(), IQueryBuilder::PARAM_BOOL);
+				$query->setParameter('flag_notjunk', $message->getFlagNotjunk(), IQueryBuilder::PARAM_BOOL);
+				$query->setParameter('flag_mdnsent', $message->getFlagMdnsent(), IQueryBuilder::PARAM_BOOL);
+				$query->setParameter('flag_important', $message->getFlagImportant(), IQueryBuilder::PARAM_BOOL);
+				$query->execute();
+				$perf->step('Updated message ' . $message->getId());
 			}
 
-			$query->setParameter('uid', $message->getUid(), IQueryBuilder::PARAM_INT);
-			$query->setParameter('mailbox_id', $message->getMailboxId(), IQueryBuilder::PARAM_INT);
-			$query->setParameter('flag_answered', $message->getFlagAnswered(), IQueryBuilder::PARAM_BOOL);
-			$query->setParameter('flag_deleted', $message->getFlagDeleted(), IQueryBuilder::PARAM_BOOL);
-			$query->setParameter('flag_draft', $message->getFlagDraft(), IQueryBuilder::PARAM_BOOL);
-			$query->setParameter('flag_flagged', $message->getFlagFlagged(), IQueryBuilder::PARAM_BOOL);
-			$query->setParameter('flag_seen', $message->getFlagSeen(), IQueryBuilder::PARAM_BOOL);
-			$query->setParameter('flag_forwarded', $message->getFlagForwarded(), IQueryBuilder::PARAM_BOOL);
-			$query->setParameter('flag_junk', $message->getFlagJunk(), IQueryBuilder::PARAM_BOOL);
-			$query->setParameter('flag_notjunk', $message->getFlagNotjunk(), IQueryBuilder::PARAM_BOOL);
-			$query->setParameter('flag_mdnsent', $message->getFlagMdnsent(), IQueryBuilder::PARAM_BOOL);
-			$query->setParameter('flag_important', $message->getFlagImportant(), IQueryBuilder::PARAM_BOOL);
-
-			$query->execute();
+			// check permflags and only go through the tagging logic if they're enabled
+			if ($permflagsEnabled) {
+				$this->updateTags($account, $message, $tags, $perf);
+			}
 		}
 
 		$this->db->commit();
+		$perf->end();
 
 		return $messages;
 	}
 
+	/**
+	 * @param Account $account
+	 * @param Message $message
+	 * @param Tag[][] $tags
+	 * @param PerformanceLoggerTask $perf
+	 */
+	private function updateTags(Account $account, Message $message, array $tags, PerformanceLoggerTask $perf): void {
+		$imapTags = $message->getTags();
+		$dbTags = $tags[$message->getMessageId()] ?? [];
+
+		if (empty($imapTags) && empty($dbTags)) {
+			// neither old nor new tags
+			return;
+		}
+
+		$toAdd = array_udiff($imapTags, $dbTags, static function (Tag $a, Tag $b) {
+			return strcmp($a->getImapLabel(), $b->getImapLabel());
+		});
+		foreach ($toAdd as $tag) {
+			$this->tagMapper->tagMessage($tag, $message->getMessageId(), $account->getUserId());
+		}
+		$perf->step("Tagged messages");
+
+		if (empty($dbTags)) {
+			// we have nothing to possibly remove
+			return;
+		}
+
+		$toRemove = array_udiff($dbTags, $imapTags, static function (Tag $a, Tag $b) {
+			return strcmp($a->getImapLabel(), $b->getImapLabel());
+		});
+		foreach ($toRemove as $tag) {
+			$this->tagMapper->untagMessage($tag, $message->getMessageId());
+		}
+		$perf->step("Untagged messages");
+	}
+
+	public function getTags(Message $message) : array {
+		$mqb = $this->db->getQueryBuilder();
+		$mqb->select('tag_id')
+			->from('mail_message_tags')
+			->where($mqb->expr()->eq('imap_message_id', $mqb->createNamedParameter($message->getMessageId())));
+		$result = $mqb->execute();
+		$ids = array_map(function (array $row) {
+			return (int)$row['tag_id'];
+		}, $result->fetchAll());
+
+		return $ids;
+	}
+
 	/**
 	 * @param Message ...$messages
 	 *
@@ -415,15 +497,27 @@ class MessageMapper extends QBMapper {
 
 	public function deleteAll(Mailbox $mailbox): void {
 		$messageIdQuery = $this->db->getQueryBuilder();
-		$deleteRecipientsQuery = $this->db->getQueryBuilder();
 		$messageIdQuery->select('id')
 			->from($this->getTableName())
-			->where($messageIdQuery->expr()->eq('mailbox_id', $deleteRecipientsQuery->createNamedParameter($mailbox->getId())));
+			->where($messageIdQuery->expr()->eq('mailbox_id', $messageIdQuery->createNamedParameter($mailbox->getId())));
 
-		// delete all related recipient entries
+		$cursor = $messageIdQuery->execute();
+		$messageIds = $cursor->fetchAll();
+		$cursor->closeCursor();
+
+		$messageIds = array_map(function (array $row) {
+			return (int)$row['id'];
+		}, $messageIds);
+
+		$deleteRecipientsQuery = $this->db->getQueryBuilder();
 		$deleteRecipientsQuery->delete('mail_recipients')
-			->where($deleteRecipientsQuery->expr()->in('message_id', $deleteRecipientsQuery->createFunction($messageIdQuery->getSQL()), IQueryBuilder::PARAM_INT_ARRAY));
-		$deleteRecipientsQuery->execute();
+			->where($deleteRecipientsQuery->expr()->in('message_id', $deleteRecipientsQuery->createParameter('ids')));
+
+		foreach (array_chunk($messageIds, 1000) as $chunk) {
+			// delete all related recipient entries
+			$deleteRecipientsQuery->setParameter('ids', $chunk, IQueryBuilder::PARAM_INT_ARRAY);
+			$deleteRecipientsQuery->execute();
+		}
 
 		$query = $this->db->getQueryBuilder();
 
@@ -436,59 +530,59 @@ class MessageMapper extends QBMapper {
 	public function deleteByUid(Mailbox $mailbox, int ...$uids): void {
 		$messageIdQuery = $this->db->getQueryBuilder();
 		$deleteRecipientsQuery = $this->db->getQueryBuilder();
+		$deleteMessagesQuery = $this->db->getQueryBuilder();
 
+		// Get all message ids query
 		$messageIdQuery->select('id')
 			->from($this->getTableName())
 			->where(
-				$messageIdQuery->expr()->eq('mailbox_id', $deleteRecipientsQuery->createNamedParameter($mailbox->getId())),
-				$messageIdQuery->expr()->in('uid', $deleteRecipientsQuery->createNamedParameter($uids, IQueryBuilder::PARAM_INT_ARRAY))
+				$messageIdQuery->expr()->eq('mailbox_id', $messageIdQuery->createNamedParameter($mailbox->getId())),
+				$messageIdQuery->expr()->in('uid', $messageIdQuery->createParameter('uids'))
 			);
-		// delete all related recipient entries
+
 		$deleteRecipientsQuery->delete('mail_recipients')
-			->where($deleteRecipientsQuery->expr()->in('message_id', $messageIdQuery->createFunction($messageIdQuery->getSQL()), IQueryBuilder::PARAM_INT_ARRAY));
-		$deleteRecipientsQuery->execute();
+			->where($deleteRecipientsQuery->expr()->in('message_id', $deleteRecipientsQuery->createParameter('messageIds')));
 
-		$query = $this->db->getQueryBuilder();
+		$deleteMessagesQuery->delete($this->getTableName())
+			->where($deleteMessagesQuery->expr()->in('id', $deleteMessagesQuery->createParameter('messageIds')));
 
-		$query->delete($this->getTableName())
-			->where(
-				$query->expr()->eq('mailbox_id', $query->createNamedParameter($mailbox->getId())),
-				$query->expr()->in('uid', $query->createNamedParameter($uids, IQueryBuilder::PARAM_INT_ARRAY))
-			);
+		foreach (array_chunk($uids, 1000) as $chunk) {
+			$messageIdQuery->setParameter('uids', $chunk, IQueryBuilder::PARAM_INT_ARRAY);
+			$cursor = $messageIdQuery->execute();
 
-		$query->execute();
+			$messageIds = array_map(function (array $message) {
+				return $message['id'];
+			}, $cursor->fetchAll());
+			$cursor->closeCursor();
+
+			// delete all related recipient entries
+			$deleteRecipientsQuery->setParameter('messageIds', $messageIds, IQueryBuilder::PARAM_INT_ARRAY);
+			$deleteRecipientsQuery->execute();
+
+			// delete all messages
+			$deleteMessagesQuery->setParameter('messageIds', $messageIds, IQueryBuilder::PARAM_INT_ARRAY);
+			$deleteMessagesQuery->execute();
+		}
 	}
 
 	/**
 	 * @param Account $account
-	 * @param int $messageId
+	 * @param string $threadRootId
 	 *
 	 * @return Message[]
 	 */
-	public function findThread(Account $account, int $messageId): array {
+	public function findThread(Account $account, string $threadRootId): array {
 		$qb = $this->db->getQueryBuilder();
-		$subQb1 = $this->db->getQueryBuilder();
-
-		$mailboxIdsQuery = $subQb1
-			->select('id')
-			->from('mail_mailboxes')
-			->where($qb->expr()->eq('account_id', $qb->createNamedParameter($account->getId(), IQueryBuilder::PARAM_INT)));
-
-		/**
-		 * Select the message with the given ID or any that has the same thread ID
-		 */
-		$selectMessages = $qb
-			->select('m2.*')
-			->from($this->getTableName(), 'm1')
-			->leftJoin('m1', $this->getTableName(), 'm2',  $qb->expr()->eq('m1.thread_root_id', 'm2.thread_root_id'))
+		$qb->select('messages.*')
+			->from($this->getTableName(), 'messages')
+			->join('messages', 'mail_mailboxes', 'mailboxes', $qb->expr()->eq('messages.mailbox_id', 'mailboxes.id', IQueryBuilder::PARAM_INT))
 			->where(
-				$qb->expr()->in('m1.mailbox_id', $qb->createFunction($mailboxIdsQuery->getSQL()), IQueryBuilder::PARAM_INT_ARRAY),
-				$qb->expr()->in('m2.mailbox_id', $qb->createFunction($mailboxIdsQuery->getSQL()), IQueryBuilder::PARAM_INT_ARRAY),
-				$qb->expr()->eq('m1.id', $qb->createNamedParameter($messageId, IQueryBuilder::PARAM_INT), IQueryBuilder::PARAM_INT),
-				$qb->expr()->isNotNull('m1.thread_root_id')
+				$qb->expr()->eq('mailboxes.account_id', $qb->createNamedParameter($account->getId(), IQueryBuilder::PARAM_INT)),
+				$qb->expr()->eq('messages.thread_root_id', $qb->createNamedParameter($threadRootId, IQueryBuilder::PARAM_STR), IQueryBuilder::PARAM_STR)
 			)
-			->orderBy('sent_at', 'desc');
-		return $this->findRecipients($this->findEntities($selectMessages));
+			->orderBy('messages.sent_at', 'desc');
+
+		return $this->findRelatedData($this->findEntities($qb), $account->getUserId());
 	}
 
 	/**
@@ -502,10 +596,14 @@ class MessageMapper extends QBMapper {
 	public function findIdsByQuery(Mailbox $mailbox, SearchQuery $query, ?int $limit, array $uids = null): array {
 		$qb = $this->db->getQueryBuilder();
 
-		$select = $qb
-			->selectDistinct('m.id')
-			->addSelect('m.sent_at')
-			->from($this->getTableName(), 'm');
+		if ($this->needDistinct($query)) {
+			$select = $qb->selectDistinct(['m.id', 'm.sent_at']);
+		} else {
+			$select = $qb->select(['m.id', 'm.sent_at']);
+		}
+
+		$select->from($this->getTableName(), 'm')
+			->leftJoin('m', $this->getTableName(), 'm2', 'm.mailbox_id = m2.mailbox_id and m.thread_root_id = m2.thread_root_id and m.sent_at < m2.sent_at');
 
 		if (!empty($query->getFrom())) {
 			$select->innerJoin('m', 'mail_recipients', 'r0', 'm.id = r0.message_id');
@@ -521,7 +619,7 @@ class MessageMapper extends QBMapper {
 		}
 
 		$select->where(
-			$qb->expr()->eq('mailbox_id', $qb->createNamedParameter($mailbox->getId()), IQueryBuilder::PARAM_INT)
+			$qb->expr()->eq('m.mailbox_id', $qb->createNamedParameter($mailbox->getId()), IQueryBuilder::PARAM_INT)
 		);
 
 		if (!empty($query->getFrom())) {
@@ -550,7 +648,7 @@ class MessageMapper extends QBMapper {
 				$qb->expr()->orX(
 					...array_map(function (string $subject) use ($qb) {
 						return $qb->expr()->iLike(
-							'subject',
+							'm.subject',
 							$qb->createNamedParameter('%' . $this->db->escapeLikeParameter($subject) . '%', IQueryBuilder::PARAM_STR),
 							IQueryBuilder::PARAM_STR
 						);
@@ -561,30 +659,41 @@ class MessageMapper extends QBMapper {
 
 		if ($query->getCursor() !== null) {
 			$select->andWhere(
-				$qb->expr()->lt('sent_at', $qb->createNamedParameter($query->getCursor(), IQueryBuilder::PARAM_INT))
+				$qb->expr()->lt('m.sent_at', $qb->createNamedParameter($query->getCursor(), IQueryBuilder::PARAM_INT))
 			);
 		}
+		// createParameter
 		if ($uids !== null) {
 			$select->andWhere(
-				$qb->expr()->in('uid', $qb->createNamedParameter($uids, IQueryBuilder::PARAM_INT_ARRAY))
+				$qb->expr()->in('m.uid', $qb->createParameter('uids'))
 			);
 		}
 		foreach ($query->getFlags() as $flag) {
-			$select->andWhere($qb->expr()->eq($this->flagToColumnName($flag), $qb->createNamedParameter($flag->isSet(), IQueryBuilder::PARAM_BOOL)));
+			$select->andWhere($qb->expr()->eq('m.' . $this->flagToColumnName($flag), $qb->createNamedParameter($flag->isSet(), IQueryBuilder::PARAM_BOOL)));
 		}
 		if (!empty($query->getFlagExpressions())) {
 			$select->andWhere(
 				...array_map(function (FlagExpression $expr) use ($select) {
-					return $this->flagExpressionToQuery($expr, $select);
+					return $this->flagExpressionToQuery($expr, $select, 'm');
 				}, $query->getFlagExpressions())
 			);
 		}
 
-		$select = $select
-			->orderBy('sent_at', 'desc');
+		$select->andWhere($qb->expr()->isNull('m2.id'));
+
+		$select->orderBy('m.sent_at', 'desc');
 
 		if ($limit !== null) {
-			$select = $select->setMaxResults($limit);
+			$select->setMaxResults($limit);
+		}
+
+		if ($uids !== null) {
+			return array_flat_map(function (array $chunk) use ($qb, $select) {
+				$qb->setParameter('uids', $chunk, IQueryBuilder::PARAM_INT_ARRAY);
+				return array_map(function (Message $message) {
+					return $message->getId();
+				}, $this->findEntities($select));
+			}, array_chunk($uids, 1000));
 		}
 
 		return array_map(function (Message $message) {
@@ -596,10 +705,14 @@ class MessageMapper extends QBMapper {
 		$qb = $this->db->getQueryBuilder();
 		$qbMailboxes = $this->db->getQueryBuilder();
 
-		$select = $qb
-			->selectDistinct('m.id')
-			->addSelect('m.sent_at')
-			->from($this->getTableName(), 'm');
+		if ($this->needDistinct($query)) {
+			$select = $qb->selectDistinct(['m.id', 'm.sent_at']);
+		} else {
+			$select = $qb->select(['m.id', 'm.sent_at']);
+		}
+
+		$select->from($this->getTableName(), 'm')
+			->leftJoin('m', $this->getTableName(), 'm2', 'm.mailbox_id = m2.mailbox_id and m.thread_root_id = m2.thread_root_id and m.sent_at < m2.sent_at');
 
 		if (!empty($query->getFrom())) {
 			$select->innerJoin('m', 'mail_recipients', 'r0', 'm.id = r0.message_id');
@@ -619,7 +732,7 @@ class MessageMapper extends QBMapper {
 			->join('mb', 'mail_accounts', 'a', $qb->expr()->eq('a.id', 'mb.account_id', IQueryBuilder::PARAM_INT))
 			->where($qb->expr()->eq('a.user_id', $qb->createNamedParameter($user->getUID())));
 		$select->where(
-			$qb->expr()->in('mailbox_id', $qb->createFunction($selectMailboxIds->getSQL()), IQueryBuilder::PARAM_INT_ARRAY)
+			$qb->expr()->in('m.mailbox_id', $qb->createFunction($selectMailboxIds->getSQL()), IQueryBuilder::PARAM_INT_ARRAY)
 		);
 
 		if (!empty($query->getFrom())) {
@@ -648,7 +761,7 @@ class MessageMapper extends QBMapper {
 				$qb->expr()->orX(
 					...array_map(function (string $subject) use ($qb) {
 						return $qb->expr()->iLike(
-							'subject',
+							'm.subject',
 							$qb->createNamedParameter('%' . $this->db->escapeLikeParameter($subject) . '%', IQueryBuilder::PARAM_STR),
 							IQueryBuilder::PARAM_STR
 						);
@@ -659,30 +772,40 @@ class MessageMapper extends QBMapper {
 
 		if ($query->getCursor() !== null) {
 			$select->andWhere(
-				$qb->expr()->lt('sent_at', $qb->createNamedParameter($query->getCursor(), IQueryBuilder::PARAM_INT))
+				$qb->expr()->lt('m.sent_at', $qb->createNamedParameter($query->getCursor(), IQueryBuilder::PARAM_INT))
 			);
 		}
 		if ($uids !== null) {
 			$select->andWhere(
-				$qb->expr()->in('uid', $qb->createNamedParameter($uids, IQueryBuilder::PARAM_INT_ARRAY))
+				$qb->expr()->in('m.uid', $qb->createParameter('uids'))
 			);
 		}
 		foreach ($query->getFlags() as $flag) {
-			$select->andWhere($qb->expr()->eq($this->flagToColumnName($flag), $qb->createNamedParameter($flag->isSet(), IQueryBuilder::PARAM_BOOL)));
+			$select->andWhere($qb->expr()->eq('m.' . $this->flagToColumnName($flag), $qb->createNamedParameter($flag->isSet(), IQueryBuilder::PARAM_BOOL)));
 		}
 		if (!empty($query->getFlagExpressions())) {
 			$select->andWhere(
 				...array_map(function (FlagExpression $expr) use ($select) {
-					return $this->flagExpressionToQuery($expr, $select);
+					return $this->flagExpressionToQuery($expr, $select, 'm');
 				}, $query->getFlagExpressions())
 			);
 		}
 
-		$select = $select
-			->orderBy('sent_at', 'desc');
+		$select->andWhere($qb->expr()->isNull('m2.id'));
+
+		$select->orderBy('m.sent_at', 'desc');
 
 		if ($limit !== null) {
-			$select = $select->setMaxResults($limit);
+			$select->setMaxResults($limit);
+		}
+
+		if ($uids !== null) {
+			return array_flat_map(function (array $chunk) use ($select) {
+				$select->setParameter('uids', $chunk, IQueryBuilder::PARAM_INT_ARRAY);
+				return array_map(function (Message $message) {
+					return $message->getId();
+				}, $this->findEntities($select));
+			}, array_chunk($uids, 1000));
 		}
 
 		return array_map(function (Message $message) {
@@ -690,17 +813,44 @@ class MessageMapper extends QBMapper {
 		}, $this->findEntities($select));
 	}
 
-	private function flagExpressionToQuery(FlagExpression $expr, IQueryBuilder $qb): string {
-		$operands = array_map(function (object $operand) use ($qb) {
+	/**
+	 * Return true when a distinct query is required.
+	 *
+	 * For the threaded message list it's necessary to self-join
+	 * the mail_messages table to figure out if we are the latest message
+	 * of a thread.
+	 *
+	 * Unfortunately a self-join on a larger table has a significant
+	 * performance impact. An database index (e.g. on thread_root_id)
+	 * could improve the query performance but adding an index is blocked by
+	 * - https://github.com/nextcloud/server/pull/25471
+	 * - https://github.com/nextcloud/mail/issues/4735
+	 *
+	 * We noticed a better query performance without distinct. As distinct is
+	 * only necessary when a search query is present (e.g. search for mail with
+	 * two recipients) it's reasonable to use distinct only for those requests.
+	 *
+	 * @param SearchQuery $query
+	 * @return bool
+	 */
+	private function needDistinct(SearchQuery $query): bool {
+		return !empty($query->getFrom())
+			|| !empty($query->getTo())
+			|| !empty($query->getCc())
+			|| !empty($query->getBcc());
+	}
+
+	private function flagExpressionToQuery(FlagExpression $expr, IQueryBuilder $qb, string $tableAlias): string {
+		$operands = array_map(function (object $operand) use ($qb, $tableAlias) {
 			if ($operand instanceof Flag) {
 				return $qb->expr()->eq(
-					$this->flagToColumnName($operand),
+					$tableAlias . '.' . $this->flagToColumnName($operand),
 					$qb->createNamedParameter($operand->isSet(), IQueryBuilder::PARAM_BOOL),
 					IQueryBuilder::PARAM_BOOL
 				);
 			}
 			if ($operand instanceof FlagExpression) {
-				return $this->flagExpressionToQuery($operand, $qb);
+				return $this->flagExpressionToQuery($operand, $qb, $tableAlias);
 			}
 
 			throw new RuntimeException('Invalid operand type ' . get_class($operand));
@@ -719,6 +869,10 @@ class MessageMapper extends QBMapper {
 	}
 
 	private function flagToColumnName(Flag $flag): string {
+		// workaround for @link https://github.com/nextcloud/mail/issues/25
+		if ($flag->getFlag() === Tag::LABEL_IMPORTANT) {
+			return "flag_important";
+		}
 		$key = ltrim($flag->getFlag(), '\\$');
 		return "flag_$key";
 	}
@@ -740,7 +894,6 @@ class MessageMapper extends QBMapper {
 				$qb->expr()->in('uid', $qb->createNamedParameter($uids, IQueryBuilder::PARAM_INT_ARRAY))
 			)
 			->orderBy('sent_at', 'desc');
-
 		return $this->findRecipients($this->findEntities($select));
 	}
 
@@ -749,21 +902,25 @@ class MessageMapper extends QBMapper {
 	 *
 	 * @return Message[]
 	 */
-	public function findByIds(array $ids): array {
+	public function findByIds(string $userId, array $ids): array {
 		if (empty($ids)) {
 			return [];
 		}
-		$qb = $this->db->getQueryBuilder();
 
-		$select = $qb
-			->select('*')
+		$qb = $this->db->getQueryBuilder();
+		$qb->select('*')
 			->from($this->getTableName())
 			->where(
-				$qb->expr()->in('id', $qb->createNamedParameter($ids, IQueryBuilder::PARAM_INT_ARRAY), IQueryBuilder::PARAM_INT_ARRAY)
+				$qb->expr()->in('id', $qb->createParameter('ids'))
 			)
 			->orderBy('sent_at', 'desc');
 
-		return $this->findRecipients($this->findEntities($select));
+		$results = [];
+		foreach (array_chunk($ids, 1000) as $chunk) {
+			$qb->setParameter('ids', $chunk, IQueryBuilder::PARAM_INT_ARRAY);
+			$results[] = $this->findRelatedData($this->findEntities($qb), $userId);
+		}
+		return array_merge(...$results);
 	}
 
 	/**
@@ -816,35 +973,65 @@ class MessageMapper extends QBMapper {
 		return $messages;
 	}
 
+	/**
+	 * @param Message[] $messages
+	 * @return Message[]
+	 */
+	public function findRelatedData(array $messages, string $userId): array {
+		$messages = $this->findRecipients($messages);
+		$tags = $this->tagMapper->getAllTagsForMessages($messages, $userId);
+		/** @var Message $message */
+		$messages = array_map(function ($message) use ($tags) {
+			$message->setTags($tags[$message->getMessageId()] ?? []);
+			return $message;
+		}, $messages);
+		return $messages;
+	}
+
 	/**
 	 * @param Mailbox $mailbox
-	 * @param int $highest
-	 *
+	 * @param array $ids
 	 * @return int[]
 	 */
 	public function findNewIds(Mailbox $mailbox, array $ids): array {
-		$qb = $this->db->getQueryBuilder();
-		$sub = $this->db->getQueryBuilder();
+		$select = $this->db->getQueryBuilder();
+		$subSelect = $this->db->getQueryBuilder();
 
-		$subSelect = $sub
-			->select($sub->func()->max('uid'))
+		$inExpression = [];
+		$notInExpression = [];
+
+		foreach (array_chunk($ids, 1000) as $chunk) {
+			$inExpression[] = $subSelect->expr()->in('id', $select->createNamedParameter($chunk, IQueryBuilder::PARAM_INT_ARRAY));
+			$notInExpression[] = $subSelect->expr()->notIn('m.id', $select->createNamedParameter($chunk, IQueryBuilder::PARAM_INT_ARRAY));
+		}
+
+		$subSelect
+			->select($subSelect->func()->min('sent_at'))
 			->from($this->getTableName())
 			->where(
-				$sub->expr()->eq('mailbox_id', $qb->createNamedParameter($mailbox->getId(), IQueryBuilder::PARAM_INT)),
-				$sub->expr()->in('id', $qb->createNamedParameter($ids, IQueryBuilder::PARAM_INT_ARRAY), IQueryBuilder::PARAM_INT_ARRAY)
+				$subSelect->expr()->eq('mailbox_id', $select->createNamedParameter($mailbox->getId(), IQueryBuilder::PARAM_INT)),
+				$subSelect->expr()->orX(...$inExpression)
 			);
-		$select = $qb
-			->select('id')
-			->from($this->getTableName())
+
+		$select
+			->select('m.id')
+			->from($this->getTableName(), 'm')
+			->leftJoin('m', $this->getTableName(), 'm2', 'm.mailbox_id = m2.mailbox_id and m.thread_root_id = m2.thread_root_id and m.sent_at < m2.sent_at')
 			->where(
-				$qb->expr()->eq('mailbox_id', $qb->createNamedParameter($mailbox->getId(), IQueryBuilder::PARAM_INT)),
-				$qb->expr()->gt('uid', $qb->createFunction('(' . $subSelect->getSQL() . ')'), IQueryBuilder::PARAM_INT)
-			);
+				$select->expr()->eq('m.mailbox_id', $select->createNamedParameter($mailbox->getId(), IQueryBuilder::PARAM_INT)),
+				$select->expr()->andX(...$notInExpression),
+				$select->expr()->gt('m.sent_at', $select->createFunction('(' . $subSelect->getSQL() . ')'), IQueryBuilder::PARAM_INT),
+				$select->expr()->isNull('m2.id')
+			)
+			->orderBy('m.sent_at', 'desc');
 
 		return $this->findIds($select);
 	}
 
-	public function findChanged(Mailbox $mailbox, int $since): array {
+	/**
+	 * Currently unused
+	 */
+	public function findChanged(Account $account, Mailbox $mailbox, int $since): array {
 		$qb = $this->db->getQueryBuilder();
 
 		$select = $qb
@@ -854,8 +1041,7 @@ class MessageMapper extends QBMapper {
 				$qb->expr()->eq('mailbox_id', $qb->createNamedParameter($mailbox->getId(), IQueryBuilder::PARAM_INT)),
 				$qb->expr()->gt('updated_at', $qb->createNamedParameter($since, IQueryBuilder::PARAM_INT))
 			);
-
-		return $this->findRecipients($this->findEntities($select));
+		return $this->findRelatedData($this->findEntities($select), $account->getUserId());
 	}
 
 	/**
@@ -864,7 +1050,7 @@ class MessageMapper extends QBMapper {
 	 *
 	 * @return Message[]
 	 */
-	public function findLatestMessages(array $mailboxIds, int $limit): array {
+	public function findLatestMessages(string $userId, array $mailboxIds, int $limit): array {
 		$qb = $this->db->getQueryBuilder();
 
 		$select = $qb
@@ -878,7 +1064,7 @@ class MessageMapper extends QBMapper {
 			->orderBy('sent_at', 'desc')
 			->setMaxResults($limit);
 
-		return $this->findRecipients($this->findEntities($select));
+		return $this->findRelatedData($this->findEntities($select), $userId);
 	}
 
 	public function deleteOrphans(): void {
@@ -894,11 +1080,12 @@ class MessageMapper extends QBMapper {
 		$result->closeCursor();
 
 		$qb2 = $this->db->getQueryBuilder();
-		$query = $qb2
-			->delete($this->getTableName())
-			->where($qb2->expr()->in('id', $qb2->createNamedParameter($ids, IQueryBuilder::PARAM_INT_ARRAY), IQueryBuilder::PARAM_INT_ARRAY));
-		$query->execute();
-
+		foreach (array_chunk($ids, 1000) as $chunk) {
+			$query = $qb2
+				->delete($this->getTableName())
+				->where($qb2->expr()->in('id', $qb2->createNamedParameter($chunk, IQueryBuilder::PARAM_INT_ARRAY), IQueryBuilder::PARAM_INT_ARRAY));
+			$query->execute();
+		}
 		$qb3 = $this->db->getQueryBuilder();
 		$recipientIdsQuery = $qb3->selectDistinct('r.id')
 			->from('mail_recipients', 'r')
@@ -911,10 +1098,12 @@ class MessageMapper extends QBMapper {
 		$result->closeCursor();
 
 		$qb4 = $this->db->getQueryBuilder();
-		$recipientsQuery = $qb4
-			->delete('mail_recipients')
-			->where($qb4->expr()->in('id', $qb4->createNamedParameter($ids, IQueryBuilder::PARAM_INT_ARRAY), IQueryBuilder::PARAM_INT_ARRAY));
-		$recipientsQuery->execute();
+		foreach (array_chunk($ids, 1000) as $chunk) {
+			$recipientsQuery = $qb4
+				->delete('mail_recipients')
+				->where($qb4->expr()->in('id', $qb4->createNamedParameter($chunk, IQueryBuilder::PARAM_INT_ARRAY), IQueryBuilder::PARAM_INT_ARRAY));
+			$recipientsQuery->execute();
+		}
 	}
 
 	public function getIdForUid(Mailbox $mailbox, $uid): ?int {
@@ -932,7 +1121,7 @@ class MessageMapper extends QBMapper {
 		if (empty($rows)) {
 			return null;
 		}
-		return (int) $rows[0]['id'];
+		return (int)$rows[0]['id'];
 	}
 
 	/**
