@@ -45,12 +45,16 @@ use JsonSerializable;
 use OC;
 use OCA\Mail\AddressList;
 use OCA\Mail\Db\LocalAttachment;
+use OCA\Mail\Db\MailAccount;
+use OCA\Mail\Db\Message;
+use OCA\Mail\Db\Tag;
 use OCA\Mail\Service\Html;
 use OCP\AppFramework\Db\DoesNotExistException;
 use OCP\Files\File;
 use OCP\Files\SimpleFS\ISimpleFile;
 use function in_array;
 use function mb_convert_encoding;
+use function mb_strcut;
 use function trim;
 
 class IMAPMessage implements IMessage, JsonSerializable {
@@ -104,6 +108,7 @@ class IMAPMessage implements IMessage, JsonSerializable {
 	public $htmlMessage = '';
 	public $plainMessage = '';
 	public $attachments = [];
+	public $inlineAttachments = [];
 	private $loadHtmlMessage = false;
 	private $hasHtmlMessage = false;
 
@@ -149,7 +154,7 @@ class IMAPMessage implements IMessage, JsonSerializable {
 			'forwarded' => in_array(Horde_Imap_Client::FLAG_FORWARDED, $flags),
 			'hasAttachments' => $this->hasAttachments($this->fetch->getStructure()),
 			'mdnsent' => in_array(Horde_Imap_Client::FLAG_MDNSENT, $flags, true),
-			'important' => in_array('$important', $flags, true)
+			'important' => in_array(Tag::LABEL_IMPORTANT, $flags, true)
 		];
 	}
 
@@ -324,19 +329,7 @@ class IMAPMessage implements IMessage, JsonSerializable {
 	 */
 	private function hasAttachments($part) {
 		foreach ($part->getParts() as $p) {
-			/** @var Horde_Mime_Part $p */
-			$filename = $p->getName();
-
-			if ($p->getContentId() !== null) {
-				continue;
-			}
-			// TODO: show embedded messages and don't treat them as attachments
-			if ($p->getType() === 'message/rfc822' || isset($filename)) {
-				// do not show technical attachments
-				if (in_array($filename, $this->attachmentsToIgnore)) {
-					continue;
-				}
-
+			if ($p->isAttachment() || $p->getType() === 'message/rfc822') {
 				return true;
 			}
 			if ($this->hasAttachments($p)) {
@@ -399,23 +392,36 @@ class IMAPMessage implements IMessage, JsonSerializable {
 	 * @return void
 	 */
 	private function getPart(Horde_Mime_Part $p, $partNo): void {
-		// ATTACHMENT
-		// Any part with a filename is an attachment,
-		// so an attached text file (type 0) is not mistaken as the message.
+		// Regular attachments
+		if ($p->isAttachment() || $p->getType() === 'message/rfc822') {
+			$this->attachments[] = [
+				'id' => $p->getMimeId(),
+				'messageId' => $this->messageId,
+				'fileName' => $p->getName(),
+				'mime' => $p->getType(),
+				'size' => $p->getBytes(),
+				'cid' => $p->getContentId(),
+				'disposition' => $p->getDisposition()
+			];
+			return;
+		}
+
+		// Inline attachments
+		// Horde doesn't consider parts with content-disposition set to inline as
+		// attachment so we need to use another way to get them.
+		// We use these inline attachments to render a message's html body in $this->getHtmlBody()
 		$filename = $p->getName();
-		// TODO: show embedded messages and don't treat them as attachments
 		if ($p->getType() === 'message/rfc822' || isset($filename)) {
 			if (in_array($filename, $this->attachmentsToIgnore)) {
 				return;
 			}
-			$this->attachments[] = [
+			$this->inlineAttachments[] = [
 				'id' => $p->getMimeId(),
 				'messageId' => $this->messageId,
 				'fileName' => $filename,
 				'mime' => $p->getType(),
 				'size' => $p->getBytes(),
-				'cid' => $p->getContentId(),
-				'disposition' => $p->getDisposition()
+				'cid' => $p->getContentId()
 			];
 			return;
 		}
@@ -430,9 +436,16 @@ class IMAPMessage implements IMessage, JsonSerializable {
 			return;
 		}
 
-		// TEXT
 		if ($p->getType() === 'text/calendar') {
-			// TODO: skip inline ics for now
+			$this->attachments[] = [
+				'id' => $p->getMimeId(),
+				'messageId' => $this->messageId,
+				'fileName' => $p->getName() ?? 'calendar.ics',
+				'mime' => $p->getType(),
+				'size' => $p->getBytes(),
+				'cid' => $p->getContentId(),
+				'disposition' => $p->getDisposition()
+			];
 			return;
 		}
 
@@ -504,7 +517,7 @@ class IMAPMessage implements IMessage, JsonSerializable {
 		return $this->htmlService->sanitizeHtmlMailBody($this->htmlMessage, [
 			'id' => $id,
 		], function ($cid) {
-			$match = array_filter($this->attachments,
+			$match = array_filter($this->inlineAttachments,
 				function ($a) use ($cid) {
 					return $a['cid'] === $cid;
 				});
@@ -673,8 +686,14 @@ class IMAPMessage implements IMessage, JsonSerializable {
 		throw new Exception('not implemented');
 	}
 
-	public function toDbMessage(int $mailboxId): \OCA\Mail\Db\Message {
-		$msg = new \OCA\Mail\Db\Message();
+	/**
+	 * Cast all values from an IMAP message into the correct DB format
+	 *
+	 * @param integer $mailboxId
+	 * @return Message
+	 */
+	public function toDbMessage(int $mailboxId, MailAccount $account): Message {
+		$msg = new Message();
 
 		$messageId = $this->getMessageId();
 		if (empty(trim($messageId))) {
@@ -692,7 +711,7 @@ class IMAPMessage implements IMessage, JsonSerializable {
 		$msg->setTo($this->getTo());
 		$msg->setCc($this->getCc());
 		$msg->setBcc($this->getBcc());
-		$msg->setSubject(mb_substr($this->getSubject(), 0, 255));
+		$msg->setSubject(mb_strcut($this->getSubject(), 0, 255));
 		$msg->setSentAt($this->getSentDate()->getTimestamp());
 
 		$flags = $this->fetch->getFlags();
@@ -706,11 +725,85 @@ class IMAPMessage implements IMessage, JsonSerializable {
 			in_array(Horde_Imap_Client::FLAG_JUNK, $flags, true) ||
 			in_array('junk', $flags, true)
 		);
-		$msg->setFlagNotjunk(in_array(Horde_Imap_Client::FLAG_NOTJUNK, $flags, true));
-		$msg->setFlagImportant(in_array('$important', $flags, true));
+		$msg->setFlagNotjunk(in_array(Horde_Imap_Client::FLAG_NOTJUNK, $flags, true) || in_array('nonjunk', $flags, true));// While this is not a standard IMAP Flag, Thunderbird uses it to mark "not junk"
+		// @todo remove this as soon as possible @link https://github.com/nextcloud/mail/issues/25
+		$msg->setFlagImportant(in_array('$important', $flags, true) || in_array('$labelimportant', $flags, true) || in_array(Tag::LABEL_IMPORTANT, $flags, true));
 		$msg->setFlagAttachments(false);
 		$msg->setFlagMdnsent(in_array(Horde_Imap_Client::FLAG_MDNSENT, $flags, true));
 
+		$allowed = [
+			Horde_Imap_Client::FLAG_ANSWERED,
+			Horde_Imap_Client::FLAG_FLAGGED,
+			Horde_Imap_Client::FLAG_FORWARDED,
+			Horde_Imap_Client::FLAG_DELETED,
+			Horde_Imap_Client::FLAG_DRAFT,
+			Horde_Imap_Client::FLAG_JUNK,
+			Horde_Imap_Client::FLAG_NOTJUNK,
+			'nonjunk', // While this is not a standard IMAP Flag, Thunderbird uses it to mark "not junk"
+			Horde_Imap_Client::FLAG_MDNSENT,
+			Horde_Imap_Client::FLAG_RECENT,
+			Horde_Imap_Client::FLAG_SEEN,
+		];
+
+		// remove all standard IMAP flags from $filters
+		$tags = array_filter($flags, function ($flag) use ($allowed) {
+			return in_array($flag, $allowed, true) === false;
+		});
+
+		if (empty($tags) === true) {
+			return $msg;
+		}
+		// cast all leftover $flags to be used as tags
+		$msg->setTags($this->generateTagEntites($tags, $account->getUserId()));
 		return $msg;
 	}
+
+	/**
+	 * Build tag entities from keywords sent by IMAP
+	 *
+	 * Will use IMAP keyword '$xxx' to create a value for
+	 * display_name like 'xxx'
+	 *
+	 * @link https://github.com/nextcloud/mail/issues/25
+	 * @link https://github.com/nextcloud/mail/issues/5150
+	 *
+	 * @param string[] $tags
+	 * @return Tag[]
+	 */
+	private function generateTagEntites(array $tags, string $userId): array {
+		$t = [];
+		foreach ($tags as $keyword) {
+			if ($keyword === '$important' || $keyword === 'important' || $keyword === '$labelimportant') {
+				$keyword = Tag::LABEL_IMPORTANT;
+			}
+			if ($keyword === '$labelwork') {
+				$keyword = Tag::LABEL_WORK;
+			}
+			if ($keyword === '$labelpersonal') {
+				$keyword = Tag::LABEL_PERSONAL;
+			}
+			if ($keyword === '$labeltodo') {
+				$keyword = Tag::LABEL_TODO;
+			}
+			if ($keyword === '$labellater') {
+				$keyword = Tag::LABEL_LATER;
+			}
+
+			$displayName = str_replace(['_', '$'], [' ', ''], $keyword);
+			$displayName = strtoupper($displayName);
+			$displayName = mb_convert_encoding($displayName, 'UTF-8', 'UTF7-IMAP');
+			$displayName = strtolower($displayName);
+			$displayName = ucwords($displayName);
+
+			$keyword = mb_strcut($keyword, 0, 64);
+			$displayName = mb_strcut($displayName, 0, 128);
+
+			$tag = new Tag();
+			$tag->setImapLabel($keyword);
+			$tag->setDisplayName($displayName);
+			$tag->setUserId($userId);
+			$t[] = $tag;
+		}
+		return $t;
+	}
 }
