@@ -26,7 +26,6 @@ namespace OCA\Mail\Service;
 use OCA\Mail\Db\Alias;
 use OCA\Mail\Db\AliasMapper;
 use OCA\Mail\Db\MailAccountMapper;
-use OCA\Mail\Exception\ClientException;
 use OCP\AppFramework\Db\DoesNotExistException;
 
 class AliasesService {
@@ -55,26 +54,23 @@ class AliasesService {
 	 * @param int $aliasId
 	 * @param string $currentUserId
 	 * @return Alias
+	 * @throws DoesNotExistException
 	 */
 	public function find(int $aliasId, string $currentUserId): Alias {
 		return $this->aliasMapper->find($aliasId, $currentUserId);
 	}
 
 	/**
-	 * @param string $currentUserId
+	 * @param string $userId
 	 * @param int $accountId
 	 * @param string $alias
 	 * @param string $aliasName
 	 *
 	 * @return Alias
-	 * @throws ClientException
+	 * @throws DoesNotExistException
 	 */
-	public function create(string $currentUserId, int $accountId, string $alias, string $aliasName): Alias {
-		try {
-			$this->mailAccountMapper->find($currentUserId, $accountId);
-		} catch (DoesNotExistException $e) {
-			throw new ClientException("Account $accountId does not exist or no permission to access it");
-		}
+	public function create(string $userId, int $accountId, string $alias, string $aliasName): Alias {
+		$this->mailAccountMapper->find($userId, $accountId);
 
 		$aliasEntity = new Alias();
 		$aliasEntity->setAccountId($accountId);
@@ -88,6 +84,7 @@ class AliasesService {
 	 * @param int $aliasId
 	 * @param String $currentUserId
 	 * @return Alias
+	 * @throws DoesNotExistException
 	 */
 	public function delete(int $aliasId, string $currentUserId): Alias {
 		$alias = $this->aliasMapper->find($aliasId, $currentUserId);
@@ -106,4 +103,18 @@ class AliasesService {
 	public function deleteAll($accountId): void {
 		$this->aliasMapper->deleteAll($accountId);
 	}
+
+	/**
+	 * Update signature for alias
+	 *
+	 * @param string $userId
+	 * @param int $aliasId
+	 * @param string|null $signature
+	 * @throws DoesNotExistException
+	 */
+	public function updateSignature(string $userId, int $aliasId, string $signature = null): void {
+		$alias = $this->find($aliasId, $userId);
+		$alias->setSignature($signature);
+		$this->aliasMapper->update($alias);
+	}
 }
