@@ -24,11 +24,12 @@ declare(strict_types=1);
 namespace OCA\Mail\Service\AutoConfig;
 
 use Exception;
+use Horde_Mail_Transport_Smtphorde;
 use OCA\Mail\Account;
 use OCA\Mail\Db\MailAccount;
 use OCA\Mail\SMTP\SmtpClientFactory;
-use OCP\ILogger;
 use OCP\Security\ICrypto;
+use Psr\Log\LoggerInterface;
 
 class SmtpConnectivityTester {
 
@@ -41,7 +42,7 @@ class SmtpConnectivityTester {
 	/** @var SmtpClientFactory */
 	private $clientFactory;
 
-	/** @var ILogger */
+	/** @var LoggerInterface */
 	private $logger;
 
 	/** @var string */
@@ -51,13 +52,13 @@ class SmtpConnectivityTester {
 	 * @param ConnectivityTester $connectivityTester
 	 * @param ICrypto $crypto
 	 * @param SmtpClientFactory $clientFactory
-	 * @param ILogger $logger
+	 * @param LoggerInterface $logger
 	 * @param string $UserId
 	 */
 	public function __construct(ConnectivityTester $connectivityTester,
 								ICrypto $crypto,
 								SmtpClientFactory $clientFactory,
-								ILogger $logger,
+								LoggerInterface $logger,
 								$UserId) {
 		$this->connectivityTester = $connectivityTester;
 		$this->crypto = $crypto;
@@ -135,6 +136,8 @@ class SmtpConnectivityTester {
 	protected function testStmtpConnection(MailAccount $mailAccount): void {
 		$account = new Account($mailAccount);
 		$smtp = $this->clientFactory->create($account);
-		$smtp->getSMTPObject();
+		if ($smtp instanceof Horde_Mail_Transport_Smtphorde) {
+			$smtp->getSMTPObject();
+		}
 	}
 }
