@@ -27,6 +27,7 @@ use HTMLPurifier_AttrTransform;
 use HTMLPurifier_Config;
 use HTMLPurifier_Context;
 use HTMLPurifier_URIParser;
+use OCP\IURLGenerator;
 
 /**
  * Adds target="_blank" to all outbound links.
@@ -38,7 +39,11 @@ class TransformHTMLLinks extends HTMLPurifier_AttrTransform {
 	 */
 	private $parser;
 
-	public function __construct() {
+	/** @var IURLGenerator */
+	private $urlGenerator;
+
+	public function __construct(IURLGenerator $urlGenerator) {
+		$this->urlGenerator = $urlGenerator;
 		$this->parser = new HTMLPurifier_URIParser();
 	}
 
@@ -53,10 +58,14 @@ class TransformHTMLLinks extends HTMLPurifier_AttrTransform {
 			return $attr;
 		}
 
-		// XXX Kind of inefficient
 		$attr['target'] = '_blank';
 		$attr['rel'] = 'noopener';
 
+		// Open mailto: links in Mail
+		if (stripos($attr['href'], 'mailto:') === 0) {
+			$attr['href'] = $this->urlGenerator->linkToRoute('mail.page.mailto') . '?to=' . substr($attr['href'], 7);
+		}
+
 		return $attr;
 	}
 }
