@@ -31,8 +31,9 @@ use OCA\Mail\Db\MailboxMapper;
 use OCA\Mail\IMAP\IMAPClientFactory;
 use OCA\Mail\IMAP\MessageMapper;
 use OCA\Mail\Integration\KItinerary\ItineraryExtractor;
+use OCP\ICache;
 use OCP\ICacheFactory;
-use OCP\ILogger;
+use Psr\Log\LoggerInterface;
 use function array_reduce;
 use function count;
 use function json_encode;
@@ -51,7 +52,10 @@ class ItineraryService {
 	/** @var ItineraryExtractor */
 	private $extractor;
 
-	/** @var ILogger */
+	/** @var ICache */
+	private $cache;
+
+	/** @var LoggerInterface */
 	private $logger;
 
 	public function __construct(IMAPClientFactory $clientFactory,
@@ -59,7 +63,7 @@ class ItineraryService {
 								MessageMapper $messageMapper,
 								ItineraryExtractor $extractor,
 								ICacheFactory $cacheFactory,
-								ILogger $logger) {
+								LoggerInterface $logger) {
 		$this->clientFactory = $clientFactory;
 		$this->mailboxMapper = $mailboxMapper;
 		$this->messageMapper = $messageMapper;
