@@ -26,13 +26,15 @@ namespace OCA\Mail\Service;
 use Horde_Imap_Client;
 use Horde_Imap_Client_Exception;
 use Horde_Imap_Client_Exception_NoSupportExtension;
-use Horde_Imap_Client_Socket;
 use OCA\Mail\Account;
 use OCA\Mail\Contracts\IMailManager;
 use OCA\Mail\Db\Mailbox;
 use OCA\Mail\Db\MailboxMapper;
 use OCA\Mail\Db\Message;
 use OCA\Mail\Db\MessageMapper as DbMessageMapper;
+use OCA\Mail\Db\Tag;
+use OCA\Mail\Db\TagMapper;
+use OCA\Mail\Db\ThreadMapper;
 use OCA\Mail\Events\BeforeMessageDeletedEvent;
 use OCA\Mail\Events\MessageDeletedEvent;
 use OCA\Mail\Events\MessageFlaggedEvent;
@@ -41,7 +43,6 @@ use OCA\Mail\Exception\ServiceException;
 use OCA\Mail\Exception\TrashMailboxNotSetException;
 use OCA\Mail\Folder;
 use OCA\Mail\IMAP\FolderMapper;
-use OCA\Mail\IMAP\FolderStats;
 use OCA\Mail\IMAP\IMAPClientFactory;
 use OCA\Mail\IMAP\MailboxSync;
 use OCA\Mail\IMAP\MessageMapper as ImapMessageMapper;
@@ -88,11 +89,16 @@ class MailManager implements IMailManager {
 
 	/** @var IEventDispatcher */
 	private $eventDispatcher;
-	/**
-	 * @var LoggerInterface
-	 */
+
+	/** @var LoggerInterface */
 	private $logger;
 
+	/** @var TagMapper */
+	private $tagMapper;
+
+	/** @var ThreadMapper */
+	private $threadMapper;
+
 	public function __construct(IMAPClientFactory $imapClientFactory,
 								MailboxMapper $mailboxMapper,
 								MailboxSync $mailboxSync,
@@ -100,7 +106,9 @@ class MailManager implements IMailManager {
 								ImapMessageMapper $messageMapper,
 								DbMessageMapper $dbMessageMapper,
 								IEventDispatcher $eventDispatcher,
-								LoggerInterface $logger) {
+								LoggerInterface $logger,
+								TagMapper $tagMapper,
+								ThreadMapper $threadMapper) {
 		$this->imapClientFactory = $imapClientFactory;
 		$this->mailboxMapper = $mailboxMapper;
 		$this->mailboxSync = $mailboxSync;
@@ -109,6 +117,8 @@ class MailManager implements IMailManager {
 		$this->dbMessageMapper = $dbMessageMapper;
 		$this->eventDispatcher = $eventDispatcher;
 		$this->logger = $logger;
+		$this->tagMapper = $tagMapper;
+		$this->threadMapper = $threadMapper;
 	}
 
 	public function getMailbox(string $uid, int $id): Mailbox {
@@ -148,30 +158,17 @@ class MailManager implements IMailManager {
 			throw new ServiceException(
 				"Could not get mailbox status: " .
 				$e->getMessage(),
-				(int) $e->getCode(),
+				(int)$e->getCode(),
 				$e
 			);
 		}
 		$this->folderMapper->detectFolderSpecialUse([$folder]);
 
-		$this->mailboxSync->sync($account, $this->logger,true);
+		$this->mailboxSync->sync($account, $this->logger, true);
 
 		return $this->mailboxMapper->find($account, $name);
 	}
 
-	/**
-	 * @param Account $account
-	 * @param Mailbox $mailbox
-	 *
-	 * @return FolderStats
-	 * @throws Horde_Imap_Client_Exception
-	 */
-	public function getMailboxStats(Account $account, Mailbox $mailbox): FolderStats {
-		$client = $this->imapClientFactory->getClient($account);
-
-		return $this->folderMapper->getFoldersStatusAsObject($client, $mailbox->getName());
-	}
-
 	public function getImapMessage(Account $account,
 								   Mailbox $mailbox,
 								   int $uid,
@@ -188,14 +185,14 @@ class MailManager implements IMailManager {
 		} catch (Horde_Imap_Client_Exception | DoesNotExistException $e) {
 			throw new ServiceException(
 				"Could not load message",
-				(int) $e->getCode(),
+				(int)$e->getCode(),
 				$e
 			);
 		}
 	}
 
-	public function getThread(Account $account, int $messageId): array {
-		return $this->dbMessageMapper->findThread($account, $messageId);
+	public function getThread(Account $account, string $threadRootId): array {
+		return $this->dbMessageMapper->findThread($account, $threadRootId);
 	}
 
 	public function getMessageIdForUid(Mailbox $mailbox, $uid): ?int {
@@ -355,7 +352,7 @@ class MailManager implements IMailManager {
 		} catch (Horde_Imap_Client_Exception $e) {
 			throw new ServiceException(
 				"Could not set subscription status for mailbox " . $mailbox->getId() . " on IMAP: " . $e->getMessage(),
-				(int) $e->getCode(),
+				(int)$e->getCode(),
 				$e
 			);
 		}
@@ -363,7 +360,7 @@ class MailManager implements IMailManager {
 		/**
 		 * 2. Pull changes into the mailbox database cache
 		 */
-		$this->mailboxSync->sync($account, $this->logger,true);
+		$this->mailboxSync->sync($account, $this->logger, true);
 
 		/**
 		 * 3. Return the updated object
@@ -393,16 +390,16 @@ class MailManager implements IMailManager {
 				if (empty($imapFlag) === true) {
 					continue;
 				}
-				if ($value === true) {
-					$this->imapMessageMapper->addFlag($client, $mb, $uid, $imapFlag);
+				if ($value) {
+					$this->imapMessageMapper->addFlag($client, $mb, [$uid], $imapFlag);
 				} else {
-					$this->imapMessageMapper->removeFlag($client, $mb, $uid, $imapFlag);
+					$this->imapMessageMapper->removeFlag($client, $mb, [$uid], $imapFlag);
 				}
 			}
 		} catch (Horde_Imap_Client_Exception $e) {
 			throw new ServiceException(
 				"Could not set message flag on IMAP: " . $e->getMessage(),
-				(int) $e->getCode(),
+				(int)$e->getCode(),
 				$e
 			);
 		}
@@ -419,6 +416,52 @@ class MailManager implements IMailManager {
 		);
 	}
 
+	/**
+	 * Tag (flag) a message on IMAP
+	 *
+	 * @param Account $account
+	 * @param string $mailbox
+	 * @param Message $message
+	 * @param Tag $tag
+	 * @param boolean $value
+	 * @return void
+	 *
+	 * @throws ClientException
+	 * @throws ServiceException
+	 * @uses
+	 *
+	 * @link https://github.com/nextcloud/mail/issues/25
+	 */
+	public function tagMessage(Account $account, string $mailbox, Message $message, Tag $tag, bool $value): void {
+		$client = $this->imapClientFactory->getClient($account);
+		try {
+			$mb = $this->mailboxMapper->find($account, $mailbox);
+		} catch (DoesNotExistException $e) {
+			throw new ClientException("Mailbox $mailbox does not exist", 0, $e);
+		}
+		if ($this->isPermflagsEnabled($account, $mailbox) === true) {
+			try {
+				if ($value) {
+					// imap keywords and flags work the same way
+					$this->imapMessageMapper->addFlag($client, $mb, [$message->getUid()], $tag->getImapLabel());
+				} else {
+					$this->imapMessageMapper->removeFlag($client, $mb, [$message->getUid()], $tag->getImapLabel());
+				}
+			} catch (Horde_Imap_Client_Exception $e) {
+				throw new ServiceException(
+					"Could not set message keyword on IMAP: " . $e->getMessage(),
+					(int)$e->getCode(),
+					$e
+				);
+			}
+		}
+		if ($value) {
+			$this->tagMapper->tagMessage($tag, $message->getMessageId(), $account->getUserId());
+		} else {
+			$this->tagMapper->untagMessage($tag, $message->getMessageId());
+		}
+	}
+
 	/**
 	 * @param Account $account
 	 *
@@ -482,7 +525,7 @@ class MailManager implements IMailManager {
 		/**
 		 * 2. Get the IMAP changes into our database cache
 		 */
-		$this->mailboxSync->sync($account, $this->logger,true);
+		$this->mailboxSync->sync($account, $this->logger, true);
 
 		/**
 		 * 3. Return the cached object with the new ID
@@ -517,10 +560,23 @@ class MailManager implements IMailManager {
 		return $this->imapMessageMapper->getAttachments($this->imapClientFactory->getClient($account), $mailbox->getName(), $message->getUid());
 	}
 
+	/**
+	 * @param string $imapLabel
+	 * @param string $userId
+	 * @return Tag
+	 * @throws ClientException
+	 */
+	public function getTagByImapLabel(string $imapLabel, string $userId): Tag {
+		try {
+			return $this->tagMapper->getTagByImapLabel($imapLabel, $userId);
+		} catch (DoesNotExistException $e) {
+			throw new ClientException('Unknown Tag', 0, $e);
+		}
+	}
+
 	/**
 	 * Filter out IMAP flags that aren't supported by the client server
 	 *
-	 * @param Horde_Imap_Client_Socket $client
 	 * @param string $flag
 	 * @param string $mailbox
 	 * @return array
@@ -534,7 +590,7 @@ class MailManager implements IMailManager {
 		// Only allow flag setting if IMAP supports Permaflags
 		// @TODO check if there are length & char limits on permflags
 		if ($this->isPermflagsEnabled($account, $mailbox) === true) {
-			return ["$" . $flag];
+			return [$flag];
 		}
 		return [];
 	}
@@ -553,10 +609,103 @@ class MailManager implements IMailManager {
 		} catch (Horde_Imap_Client_Exception $e) {
 			throw new ServiceException(
 				"Could not get message flag options from IMAP: " . $e->getMessage(),
-				(int) $e->getCode(),
+				(int)$e->getCode(),
 				$e
 			);
 		}
 		return (is_array($capabilities) === true && array_key_exists('permflags', $capabilities) === true && in_array("\*", $capabilities['permflags'], true) === true);
 	}
+
+	public function createTag(string $displayName, string $color, string $userId): Tag {
+		$imapLabel = str_replace(' ', '_', $displayName);
+		/** @var string|false $imapLabel */
+		$imapLabel = mb_convert_encoding($imapLabel, 'UTF7-IMAP', 'UTF-8');
+		if ($imapLabel === false) {
+			throw new ClientException('Error converting display name to UTF7-IMAP ', 0);
+		}
+		$imapLabel = '$' . strtolower(mb_strcut($imapLabel, 0, 63));
+
+		try {
+			return $this->getTagByImapLabel($imapLabel, $userId);
+		} catch (ClientException $e) {
+			// it's valid that a tag does not exist.
+		}
+
+		$tag = new Tag();
+		$tag->setUserId($userId);
+		$tag->setDisplayName($displayName);
+		$tag->setImapLabel($imapLabel);
+		$tag->setColor($color);
+		$tag->setIsDefaultTag(false);
+
+		return $this->tagMapper->insert($tag);
+	}
+
+	public function updateTag(int $id, string $displayName, string $color, string $userId): Tag {
+		try {
+			$tag = $this->tagMapper->getTagForUser($id, $userId);
+		} catch (DoesNotExistException $e) {
+			throw new ClientException('Tag not found', 0, $e);
+		}
+
+		$tag->setDisplayName($displayName);
+		$tag->setColor($color);
+
+		return $this->tagMapper->update($tag);
+	}
+
+	public function moveThread(Account $srcAccount, Mailbox $srcMailbox, Account $dstAccount, Mailbox $dstMailbox, string $threadRootId): void {
+		$mailAccount = $srcAccount->getMailAccount();
+		$messageInTrash = $srcMailbox->getId() === $mailAccount->getTrashMailboxId();
+
+		$messages = $this->threadMapper->findMessageUidsAndMailboxNamesByAccountAndThreadRoot(
+			$mailAccount,
+			$threadRootId,
+			$messageInTrash
+		);
+
+		foreach ($messages as $message) {
+			$this->logger->debug('move message', [
+				'messageId' => $message['messageUid'],
+				'srcMailboxId' => $srcMailbox->getId(),
+				'dstMailboxId' => $dstMailbox->getId()
+			]);
+
+			$this->moveMessage(
+				$srcAccount,
+				$message['mailboxName'],
+				$message['messageUid'],
+				$dstAccount,
+				$dstMailbox->getName()
+			);
+		}
+	}
+
+	/**
+	 * @throws ClientException
+	 * @throws ServiceException
+	 */
+	public function deleteThread(Account $account, Mailbox $mailbox, string $threadRootId): void {
+		$mailAccount = $account->getMailAccount();
+		$messageInTrash = $mailbox->getId() === $mailAccount->getTrashMailboxId();
+
+		$messages = $this->threadMapper->findMessageUidsAndMailboxNamesByAccountAndThreadRoot(
+			$mailAccount,
+			$threadRootId,
+			$messageInTrash
+		);
+
+		foreach ($messages as $message) {
+			$this->logger->debug('deleting message', [
+				'messageId' => $message['messageUid'],
+				'mailboxId' => $mailbox->getId(),
+			]);
+
+			$this->deleteMessage(
+				$account,
+				$message['mailboxName'],
+				$message['messageUid']
+			);
+		}
+	}
 }
