@@ -28,6 +28,7 @@ namespace OCA\Mail\Service\Sync;
 use Horde_Imap_Client;
 use Horde_Imap_Client_Exception;
 use OCA\Mail\Account;
+use OCA\Mail\Contracts\IMailManager;
 use OCA\Mail\Db\Mailbox;
 use OCA\Mail\Db\MailboxMapper;
 use OCA\Mail\Db\MessageMapper as DatabaseMessageMapper;
@@ -84,6 +85,9 @@ class ImapToDbSynchronizer {
 	/** @var LoggerInterface */
 	private $logger;
 
+	/** @var IMailManager */
+	private $mailManager;
+
 	public function __construct(DatabaseMessageMapper $dbMapper,
 								IMAPClientFactory $clientFactory,
 								ImapMessageMapper $imapMapper,
@@ -92,7 +96,8 @@ class ImapToDbSynchronizer {
 								Synchronizer $synchronizer,
 								IEventDispatcher $dispatcher,
 								PerformanceLogger $performanceLogger,
-								LoggerInterface $logger) {
+								LoggerInterface $logger,
+								IMailManager $mailManager) {
 		$this->dbMapper = $dbMapper;
 		$this->clientFactory = $clientFactory;
 		$this->imapMapper = $imapMapper;
@@ -102,6 +107,7 @@ class ImapToDbSynchronizer {
 		$this->dispatcher = $dispatcher;
 		$this->performanceLogger = $performanceLogger;
 		$this->logger = $logger;
+		$this->mailManager = $mailManager;
 	}
 
 	/**
@@ -114,10 +120,10 @@ class ImapToDbSynchronizer {
 								int $criteria = Horde_Imap_Client::SYNC_NEWMSGSUIDS | Horde_Imap_Client::SYNC_FLAGSUIDS | Horde_Imap_Client::SYNC_VANISHEDUIDS): void {
 		foreach ($this->mailboxMapper->findAll($account) as $mailbox) {
 			if (!$mailbox->isInbox() && !$mailbox->getSyncInBackground()) {
-				$logger->debug("Skipping mailbox sync for " . $mailbox->getName());
+				$logger->debug("Skipping mailbox sync for " . $mailbox->getId());
 				continue;
 			}
-
+			$logger->debug("Syncing " . $mailbox->getId());
 			$this->sync(
 				$account,
 				$mailbox,
@@ -215,19 +221,23 @@ class ImapToDbSynchronizer {
 				|| $mailbox->getSyncNewToken() === null
 				|| $mailbox->getSyncChangedToken() === null
 				|| $mailbox->getSyncVanishedToken() === null) {
+				$logger->debug("Running initial sync for " . $mailbox->getId());
 				$this->runInitialSync($account, $mailbox, $logger);
 			} else {
 				try {
+					$logger->debug("Running partial sync for " . $mailbox->getId());
 					$this->runPartialSync($account, $mailbox, $logger, $criteria, $knownUids);
 				} catch (UidValidityChangedException $e) {
-					$logger->warning('Mailbox UID validity changed. Wiping cache and performing full sync.');
+					$logger->warning('Mailbox UID validity changed. Wiping cache and performing full sync for ' . $mailbox->getId());
 					$this->resetCache($account, $mailbox);
+					$logger->debug("Running initial sync for " . $mailbox->getId() . " after cache reset");
 					$this->runInitialSync($account, $mailbox, $logger);
 				} catch (MailboxDoesNotSupportModSequencesException $e) {
-					$logger->warning('Mailbox does not support mod-sequences error occured. Wiping cache and performing full sync.', [
+					$logger->warning('Mailbox does not support mod-sequences error occured. Wiping cache and performing full sync for ' . $mailbox->getId(), [
 						'exception' => $e,
 					]);
 					$this->resetCache($account, $mailbox);
+					$logger->debug("Running initial sync for " . $mailbox->getId() . " after cache reset - no mod-sequences error");
 					$this->runInitialSync($account, $mailbox, $logger);
 				}
 			}
@@ -288,8 +298,8 @@ class ImapToDbSynchronizer {
 		}
 
 		foreach (array_chunk($imapMessages['messages'], 500) as $chunk) {
-			$this->dbMapper->insertBulk(...array_map(function (IMAPMessage $imapMessage) use ($mailbox) {
-				return $imapMessage->toDbMessage($mailbox->getId());
+			$this->dbMapper->insertBulk($account, ...array_map(function (IMAPMessage $imapMessage) use ($mailbox, $account) {
+				return $imapMessage->toDbMessage($mailbox->getId(), $account->getMailAccount());
 			}, $chunk));
 		}
 		$perf->step('persist messages in database');
@@ -345,17 +355,17 @@ class ImapToDbSynchronizer {
 			$perf->step('get new messages via Horde');
 
 			foreach (array_chunk($response->getNewMessages(), 500) as $chunk) {
-				$dbMessages = array_map(function (IMAPMessage $imapMessage) use ($mailbox) {
-					return $imapMessage->toDbMessage($mailbox->getId());
+				$dbMessages = array_map(function (IMAPMessage $imapMessage) use ($mailbox, $account) {
+					return $imapMessage->toDbMessage($mailbox->getId(), $account->getMailAccount());
 				}, $chunk);
 
+				$this->dbMapper->insertBulk($account, ...$dbMessages);
+
 				$this->dispatcher->dispatch(
 					NewMessagesSynchronized::class,
 					new NewMessagesSynchronized($account, $mailbox, $dbMessages)
 				);
 				$perf->step('classified a chunk of new messages');
-
-				$this->dbMapper->insertBulk(...$dbMessages);
 			}
 			$perf->step('persist new messages');
 
@@ -373,9 +383,11 @@ class ImapToDbSynchronizer {
 			);
 			$perf->step('get changed messages via Horde');
 
+			$permflagsEnabled = $this->mailManager->isPermflagsEnabled($account, $mailbox->getName());
+
 			foreach (array_chunk($response->getChangedMessages(), 500) as $chunk) {
-				$this->dbMapper->updateBulk(...array_map(function (IMAPMessage $imapMessage) use ($mailbox) {
-					return $imapMessage->toDbMessage($mailbox->getId());
+				$this->dbMapper->updateBulk($account, $permflagsEnabled, ...array_map(static function (IMAPMessage $imapMessage) use ($mailbox, $account) {
+					return $imapMessage->toDbMessage($mailbox->getId(), $account->getMailAccount());
 				}, $chunk));
 			}
 			$perf->step('persist changed messages');
