@@ -28,10 +28,8 @@ style('mail', 'mobile');
 script('mail', 'mail');
 ?>
 
-<input type="hidden" id="debug-mode" value="<?php p($_['debug'] ? 'true' : 'false'); ?>">
 <input type="hidden" id="attachment-size-limit" value="<?php p($_['attachment-size-limit']); ?>">
 <input type="hidden" id="config-installed-version" value="<?php p($_['app-version']); ?>">
-<input type="hidden" id="serialized-accounts" value="<?php p($_['accounts']); ?>">
 <input type="hidden" id="external-avatars" value="<?php p($_['external-avatars']); ?>">
 <input type="hidden" id="collect-data" value="<?php p($_['collect-data']); ?>">
-<input type="hidden" id="account-settings" value="<?php p($_['account-settings']); ?>">
+<input type="hidden" id="tag-classified-messages" value="<?php p($_['tag-classified-messages']); ?>">
